<?php
unset($pia_lang);
//////////////////////////////////////////////////////////////////
// About
//////////////////////////////////////////////////////////////////
$pia_lang['About_Title'] = 'Guardia di Rete Open Source';
$pia_lang['About_Exit'] = 'Esci';
$pia_lang['About_Reports'] = 'Mostra Report';

//////////////////////////////////////////////////////////////////
// General
//////////////////////////////////////////////////////////////////
$pia_lang['Gen_Delete'] = 'Elimina';
$pia_lang['Gen_Cancel'] = 'Annulla';
$pia_lang['Gen_Okay'] = 'Ok';
$pia_lang['Gen_Purge'] = 'Pulisci';
$pia_lang['Gen_Backup'] = 'Backup';
$pia_lang['Gen_Restore'] = 'Ripristina';
$pia_lang['Gen_Switch'] = 'Cambia';
$pia_lang['Gen_Run'] = 'Esegui';
$pia_lang['Gen_Save'] = 'Salva';
$pia_lang['Gen_Close'] = 'Chiudi';
$pia_lang['Gen_on'] = 'Acceso';
$pia_lang['Gen_off'] = 'Spento';

//////////////////////////////////////////////////////////////////
// Login Page
//////////////////////////////////////////////////////////////////

$pia_lang['Login_Box'] = 'Inserisci la password';
$pia_lang['Login_Remember'] = 'Ricorda la password';
$pia_lang['Login_Remember_small'] = '(valida per 7 giorni)';
$pia_lang['Login_Submit'] = 'Accedi';
$pia_lang['Login_Psw_run'] = 'Per cambiare la password, usa:';
$pia_lang['Login_Psw_new'] = 'la_tua_password';
$pia_lang['Login_Psw_folder'] = 'nella cartella "~/pialert/back"';
$pia_lang['Login_Psw_alert'] = 'Avviso di sicurezza!';
$pia_lang['Login_Psw-box'] = 'Password';
$pia_lang['Login_Toggle_Info'] = 'Informazioni sulla password';
$pia_lang['Login_Toggle_Info_headline'] = 'Informazioni sulla password';
$pia_lang['Login_Toggle_Alert_headline'] = 'Avviso password!';

//////////////////////////////////////////////////////////////////
// Sidebar
//////////////////////////////////////////////////////////////////

$pia_lang['Navigation_Devices'] = 'Dispositivi';
$pia_lang['Navigation_Services'] = 'Servizi Web';
$pia_lang['Navigation_Presence'] = 'Presenza';
$pia_lang['Navigation_Events'] = 'Eventi';
$pia_lang['Navigation_Journal'] = 'Registro Pi.Alert';
$pia_lang['Navigation_Events_Dev'] = 'Dispositivi';
$pia_lang['Navigation_Events_Serv'] = 'Servizi Web';
$pia_lang['Navigation_ICMPScan'] = 'Monitoraggio ICMP';
$pia_lang['Navigation_Maintenance'] = 'Impostazioni';
$pia_lang['Navigation_Network'] = 'Rete';
$pia_lang['Navigation_HelpFAQ'] = 'Aiuto / FAQ';
$pia_lang['Navigation_UpdateCheck'] = 'Verifica Aggiornamenti';
$pia_lang['Navigation_Section_A'] = 'FUNZIONI PRINCIPALI';
$pia_lang['Navigation_Section_B'] = 'EVENTI E REGISTRO';
$pia_lang['Navigation_Section_C'] = 'IMPOSTAZIONI E AIUTO';

//////////////////////////////////////////////////////////////////
// Device Page
//////////////////////////////////////////////////////////////////

$pia_lang['Device_Title'] = 'Dispositivi';
$pia_lang['Device_Shortcut_AllDevices'] = 'Tutti i Dispositivi';
$pia_lang['Device_Shortcut_Connected'] = 'Connessi';
$pia_lang['Device_Shortcut_Favorites'] = 'Preferiti';
$pia_lang['Device_Shortcut_NewDevices'] = 'Nuovi Dispositivi';
$pia_lang['Device_Shortcut_DownAlerts'] = 'Allarmi Disconnessione';
$pia_lang['Device_Shortcut_Archived'] = 'Archiviati';
$pia_lang['Device_Shortcut_Devices'] = 'Dispositivi';
$pia_lang['Device_Shortcut_OnlineChart_a'] = 'Attività di rete nell\'ultime ';
$pia_lang['Device_Shortcut_OnlineChart_b'] = ' ore';
$pia_lang['Device_TableHead_Name'] = 'Nome';
$pia_lang['Device_TableHead_Owner'] = 'Proprietario';
$pia_lang['Device_TableHead_Type'] = 'Tipo di Dispositivo';
$pia_lang['Device_TableHead_Favorite'] = 'Preferito';
$pia_lang['Device_TableHead_Group'] = 'Gruppo';
$pia_lang['Device_TableHead_Location'] = 'Posizione';
$pia_lang['Device_TableHead_FirstSession'] = 'Prima Sessione';
$pia_lang['Device_TableHead_LastSession'] = 'Ultima Sessione';
$pia_lang['Device_TableHead_LastIP'] = 'Ultimo IP';
$pia_lang['Device_TableHead_MAC'] = 'MAC';
$pia_lang['Device_TableHead_MACaddress'] = 'Indirizzo MAC';
$pia_lang['Device_TableHead_LastIPOrder'] = 'Ultimo Ordine IP';
$pia_lang['Device_TableHead_Rowid'] = 'Numero di Riga';
$pia_lang['Device_TableHead_Status'] = 'Stato';
$pia_lang['Device_TableHead_ConnectionType'] = 'Tipo di Connessione';
$pia_lang['Device_Searchbox'] = 'Ricerca';
$pia_lang['Device_Tablelenght'] = 'Mostra _MENU_ voci';
$pia_lang['Device_Tablelenght_all'] = 'Tutte';
$pia_lang['Device_Table_info'] = 'Visualizzazione _START_ a _END_ di _TOTAL_ voci';
$pia_lang['Device_Table_nav_next'] = 'Successivo';
$pia_lang['Device_Table_nav_prev'] = 'Precedente';
$pia_lang['Device_bulkEditor_mode'] = 'Editor Multipli';
$pia_lang['Device_bulkEditor_mode_quit'] = 'Esci dall\'Editor';
$pia_lang['Device_bulkEditor_selectall'] = 'Seleziona Tutti';
$pia_lang['Device_bulkEditor_selectnone'] = 'Deseleziona Tutti';
$pia_lang['Device_bulkEditor_savebox_title'] = 'I campi sono stati salvati';
$pia_lang['Device_bulkEditor_savebox_noselection'] = 'Nessun campo è stato selezionato per la modifica';
$pia_lang['Device_bulkEditor_savebox_mod_devices'] = 'Dispositivi Modificati';
$pia_lang['Device_bulkEditor_savebox_mod_fields'] = 'Campi Modificati';
$pia_lang['Device_bulkEditor_hostbox_title'] = 'Seleziona i dispositivi da modificare';
$pia_lang['Device_bulkEditor_inputbox_title'] = 'Modifica Campi';
$pia_lang['Device_bulkDel_button'] = 'ELIMINA DISPOSITIVI';
$pia_lang['Device_bulkDel_info_head'] = 'Elimina Più Dispositivi';
$pia_lang['Device_bulkDel_info_text'] = 'Con questa funzione è possibile eliminare uno o più dispositivi dal database. Se i dispositivi sono ancora nella rete, potrebbero essere reintegrati nel database, ma senza le loro impostazioni individuali.';
$pia_lang['Device_bulkDel_back_before'] = 'Numero di dispositivi prima';
$pia_lang['Device_bulkDel_back_after'] = 'Numero di dispositivi ora';
$pia_lang['Device_bulkDel_back_hosts'] = 'Indirizzi MAC da eliminare';

//////////////////////////////////////////////////////////////////
// Presence Page
//////////////////////////////////////////////////////////////////

$pia_lang['Presence_Title'] = 'Presenza per dispositivo';
$pia_lang['Presence_Shortcut_AllDevices'] = 'Tutti i dispositivi';
$pia_lang['Presence_Shortcut_Connected'] = 'Connessi';
$pia_lang['Presence_Shortcut_Favorites'] = 'Preferiti';
$pia_lang['Presence_Shortcut_NewDevices'] = 'Nuovi dispositivi';
$pia_lang['Presence_Shortcut_DownAlerts'] = 'Segnalazioni inattive';
$pia_lang['Presence_Shortcut_Archived'] = 'Archiviato';
$pia_lang['Presence_Shortcut_Devices'] = 'Dispositivi';

// Localizationfiles under pialert/front/lib/AdminLTE/bower_components/fullcalendar/dist/locale
$pia_lang['Presence_CallHead_Devices'] = 'Dispositivi';
$pia_lang['Presence_CalHead_lang'] = 'it';
$pia_lang['Presence_CalHead_year'] = 'Anno';
$pia_lang['Presence_CalHead_quarter'] = 'Trimestre';
$pia_lang['Presence_CalHead_month'] = 'Mese';
$pia_lang['Presence_CalHead_week'] = 'Settimana';
$pia_lang['Presence_CalHead_day'] = 'Giorno';

//////////////////////////////////////////////////////////////////
// Events Page
//////////////////////////////////////////////////////////////////

$pia_lang['Events_Title'] = 'Eventi del dispositivo';
$pia_lang['Events_Periodselect_today'] = 'Oggi';
$pia_lang['Events_Periodselect_LastWeek'] = 'Settimana scorsa';
$pia_lang['Events_Periodselect_LastMonth'] = 'Mese scorso';
$pia_lang['Events_Periodselect_LastYear'] = 'Anno scorso';
$pia_lang['Events_Periodselect_All'] = 'Tutti gli eventi';
$pia_lang['Events_Shortcut_AllEvents'] = 'Tutti gli eventi';
$pia_lang['Events_Shortcut_Sessions'] = 'Sessioni';
$pia_lang['Events_Shortcut_MissSessions'] = 'Sessioni mancanti';
$pia_lang['Events_Shortcut_VoidSessions'] = 'Sessioni vuote';
$pia_lang['Events_Shortcut_NewDevices'] = 'Nuovi dispositivi';
$pia_lang['Events_Shortcut_DownAlerts'] = 'Segnalazioni inattive';
$pia_lang['Events_Shortcut_Events'] = 'Eventi';
$pia_lang['Events_TableHead_Order'] = 'Ordine';
$pia_lang['Events_TableHead_Device'] = 'Dispositivo';
$pia_lang['Events_TableHead_Owner'] = 'Proprietario';
$pia_lang['Events_TableHead_Date'] = 'Data';
$pia_lang['Events_TableHead_EventType'] = 'Tipo di evento';
$pia_lang['Events_TableHead_Connection'] = 'Connessione';
$pia_lang['Events_TableHead_Disconnection'] = 'Disconnessione';
$pia_lang['Events_TableHead_Duration'] = 'Durata';
$pia_lang['Events_TableHead_DurationOrder'] = 'Ordine di durata';
$pia_lang['Events_TableHead_IP'] = 'IP';
$pia_lang['Events_TableHead_IPOrder'] = 'Ordine IP';
$pia_lang['Events_TableHead_AdditionalInfo'] = 'Informazioni aggiuntive';
$pia_lang['Events_Searchbox'] = 'Cerca';
$pia_lang['Events_Tablelenght'] = 'Mostra _MENU_ voci';
$pia_lang['Events_Tablelenght_all'] = 'Tutto';
$pia_lang['Events_Table_info'] = 'Mostra _START_ a _END_ di _TOTAL_ voci';
$pia_lang['Events_Table_nav_next'] = 'Successiva';
$pia_lang['Events_Table_nav_prev'] = 'Precedente';

//////////////////////////////////////////////////////////////////
// WebServices Events Page
//////////////////////////////////////////////////////////////////

$pia_lang['WebServices_Events_Title'] = 'Servizi Web - Eventi';
$pia_lang['WebServices_Events_Shortcut_All'] = 'Tutti gli eventi';
$pia_lang['WebServices_Events_Shortcut_HTTP2xx'] = 'Codice HTTP 2xx';
$pia_lang['WebServices_Events_Shortcut_HTTP3xx'] = 'Codice HTTP 3xx';
$pia_lang['WebServices_Events_Shortcut_HTTP4xx'] = 'Codice HTTP 4xx';
$pia_lang['WebServices_Events_Shortcut_HTTP5xx'] = 'Codice HTTP 5xx';
$pia_lang['WebServices_Events_Shortcut_Down'] = 'Inattivo';
$pia_lang['WebServices_Events_TableHead_URL'] = 'URL del servizio web';
$pia_lang['WebServices_Events_TableHead_TargetIP'] = 'IP di destinazione';
$pia_lang['WebServices_Events_TableHead_ScanTime'] = 'Data';
$pia_lang['WebServices_Events_TableHead_StatusCode'] = 'Stato HTTP';
$pia_lang['WebServices_Events_TableHead_ResponsTime'] = 'Tempo di risposta';

//////////////////////////////////////////////////////////////////
// Device Details Page
//////////////////////////////////////////////////////////////////

$pia_lang['DevDetail_Periodselect_today'] = 'Oggi';
$pia_lang['DevDetail_Periodselect_LastWeek'] = 'Settimana scorsa';
$pia_lang['DevDetail_Periodselect_LastMonth'] = 'Mese scorso';
$pia_lang['DevDetail_Periodselect_LastYear'] = 'Anno scorso';
$pia_lang['DevDetail_Periodselect_All'] = 'Tutte le informazioni';
$pia_lang['DevDetail_Shortcut_CurrentStatus'] = 'Stato attuale';
$pia_lang['DevDetail_Shortcut_Sessions'] = 'Sessioni';
$pia_lang['DevDetail_Shortcut_Presence'] = 'Presenza';
$pia_lang['DevDetail_Shortcut_DownAlerts'] = 'Segnalazioni inattive';
$pia_lang['DevDetail_Tab_Details'] = 'Dettagli';
$pia_lang['DevDetail_Tab_Nmap'] = 'Strumenti';
$pia_lang['DevDetail_Tab_Sessions'] = 'Sessioni';
$pia_lang['DevDetail_Tab_Presence'] = 'Presenza';
$pia_lang['DevDetail_Tab_Events'] = 'Eventi';
$pia_lang['DevDetail_MainInfo_Title'] = 'Informazioni principali';
$pia_lang['DevDetail_MainInfo_mac'] = 'MAC';
$pia_lang['DevDetail_MainInfo_Name'] = 'Nome';
$pia_lang['DevDetail_MainInfo_Owner'] = 'Proprietario';
$pia_lang['DevDetail_MainInfo_Type'] = 'Tipo';
$pia_lang['DevDetail_MainInfo_Vendor'] = 'Produttore';
$pia_lang['DevDetail_MainInfo_Model'] = 'Modello';
$pia_lang['DevDetail_MainInfo_Serialnumber'] = 'Numero seriale';
$pia_lang['DevDetail_MainInfo_Favorite'] = 'Preferito';
$pia_lang['DevDetail_MainInfo_Group'] = 'Gruppo';
$pia_lang['DevDetail_MainInfo_Location'] = 'Posizione';
$pia_lang['DevDetail_MainInfo_Comments'] = 'Note';
$pia_lang['DevDetail_MainInfo_Network'] = 'Uplink Destinazione';
$pia_lang['DevDetail_MainInfo_Network_Port'] = 'Numero porta di destinazione';
$pia_lang['DevDetail_MainInfo_Network_ConnectType'] = 'Tipo di connessione';
$pia_lang['DevDetail_SessionInfo_Title'] = 'Informazioni sessione';
$pia_lang['DevDetail_SessionInfo_Status'] = 'Stato';
$pia_lang['DevDetail_SessionInfo_FirstSession'] = 'Prima sessione';
$pia_lang['DevDetail_SessionInfo_LastSession'] = 'Ultima sessione';
$pia_lang['DevDetail_SessionInfo_LastIP'] = 'Ultimo IP';
$pia_lang['DevDetail_SessionInfo_StaticIP'] = 'IP statico';
$pia_lang['DevDetail_Network_Titel'] = 'Rete';
$pia_lang['DevDetail_EveandAl_Title'] = 'Configura eventi e allarmi';
$pia_lang['DevDetail_EveandAl_ScanCycle'] = 'Intervallo scansione';
$pia_lang['DevDetail_EveandAl_AlertAllEvents'] = 'Segnala tutti gli eventi';
$pia_lang['DevDetail_EveandAl_AlertDown'] = 'Segnala down';
$pia_lang['DevDetail_EveandAl_Skip'] = 'Sospendi notifiche ripetute per';
$pia_lang['DevDetail_EveandAl_NewDevice'] = 'Nuovo dispositivo';
$pia_lang['DevDetail_EveandAl_Archived'] = 'Archiviato';
$pia_lang['DevDetail_EveandAl_RandomMAC'] = 'MAC casuale';
$pia_lang['DevDetail_EveandAl_ScanCycle_a'] = 'Scansione dispositivo (1 min)';
$pia_lang['DevDetail_EveandAl_ScanCycle_z'] = 'Non scansionare dispositivo (0 min)';
$pia_lang['DevDetail_button_Delete'] = 'Elimina dispositivo';
$pia_lang['DevDetail_button_Delete_Warning'] = 'Sei sicuro di voler eliminare questo dispositivo?';
$pia_lang['DevDetail_button_Reset'] = 'Annulla';
$pia_lang['DevDetail_button_Save'] = 'Salva';
$pia_lang['DevDetail_button_DeleteEvents'] = 'Elimina eventi';
$pia_lang['DevDetail_button_DeleteEvents_Warning'] = 'Sei sicuro di voler eliminare tutti gli eventi di questo dispositivo? (Questa operazione cancellerà la cronologia degli eventi e le sessioni, potrebbe aiutare con notifiche persistenti)';
$pia_lang['DevDetail_SessionTable_Order'] = 'Ordine';
$pia_lang['DevDetail_SessionTable_Connection'] = 'Connessione';
$pia_lang['DevDetail_SessionTable_Disconnection'] = 'Disconnessione';
$pia_lang['DevDetail_SessionTable_Duration'] = 'Durata';
$pia_lang['DevDetail_SessionTable_IP'] = 'IP';
$pia_lang['DevDetail_SessionTable_Additionalinfo'] = 'Informazioni aggiuntive';
$pia_lang['DevDetail_Events_CheckBox'] = 'Nascondi eventi di connessione';
$pia_lang['DevDetail_Tools_nmap_buttonFast'] = 'Scansione rapida';
$pia_lang['DevDetail_Tools_nmap_buttonDefault'] = 'Scansione predefinita';
$pia_lang['DevDetail_Tools_nmap_buttonDetail'] = 'Scansione dettagliata';
$pia_lang['DevDetail_Tools_nmap_buttonFast_text'] = 'Scansione rapida: controlla solo le prime 100 porte più importanti (alcuni secondi)';
$pia_lang['DevDetail_Tools_nmap_buttonDefault_text'] = 'Scansione predefinita: Nmap esegue una scansione delle prime 1.000 porte per ogni protocollo richiesto. Ciò copre circa il 93% delle porte TCP e il 49% delle porte UDP (circa 5-10 secondi)';
$pia_lang['DevDetail_Tools_nmap_buttonDetail_text'] = 'Scansione dettagliata: Scansione predefinita con rilevamento del sistema operativo, rilevamento della versione, scansione degli script e traceroute (fino a 30 o più secondi)';
$pia_lang['DevDetail_Tools_WOL'] = 'Invia comando Wake-on-LAN a ';
$pia_lang['DevDetail_Tools_WOL_noti'] = 'Wake-on-LAN';
$pia_lang['DevDetail_Tools_WOL_noti_text'] = 'Il comando Wake-on-LAN viene inviato all&apos;indirizzo di broadcast. Se la destinazione non è nella stessa subnet/VLAN di Pi.Alert, il dispositivo di destinazione potrebbe non rispondere.';
$pia_lang['BackDevDetail_Tools_WOL_okay'] = 'Il comando è stato eseguito';
$pia_lang['BackDevDetail_Tools_WOL_error'] = 'Il comando non è stato eseguito';

//////////////////////////////////////////////////////////////////
// WebServices Details Page
//////////////////////////////////////////////////////////////////

$pia_lang['WebServices_Title'] = 'Servizi Web';
$pia_lang['WebServices_unknown_Device'] = 'Dispositivo sconosciuto';
$pia_lang['WebServices_tablehead_TargetIP'] = 'IP di destinazione';
$pia_lang['WebServices_tablehead_ScanTime'] = 'Orario aggiornamento';
$pia_lang['WebServices_tablehead_Status_Code'] = 'Codice di stato HTTP';
$pia_lang['WebServices_tablehead_Response_Time'] = 'Tempo di risposta';
$pia_lang['WebServices_Tab_Graph'] = 'Grafico';
$pia_lang['WebServices_label_URL'] = 'URL del servizio';
$pia_lang['WebServices_label_Tags'] = 'Tag';
$pia_lang['WebServices_label_MAC'] = 'Dispositivo';
$pia_lang['WebServices_label_MAC_Select'] = 'Seleziona';
$pia_lang['WebServices_label_Notes'] = 'Note';
$pia_lang['WebServices_label_TargetIP'] = 'IP di destinazione';
$pia_lang['WebServices_label_StatusCode'] = 'Codice di stato HTTP';
$pia_lang['WebServices_label_ScanTime'] = 'Orario aggiornamento';
$pia_lang['WebServices_label_Response_Time'] = 'Tempo di risposta';
$pia_lang['WebServices_label_AlertEvents'] = 'Tutti gli eventi';
$pia_lang['WebServices_label_AlertDown'] = 'Disattiva';
$pia_lang['WebServices_label_Notification'] = 'Notifica';
$pia_lang['WebServices_Chart_a'] = 'Stato del servizio nelle ultime';
$pia_lang['WebServices_Chart_b'] = 'ore';
$pia_lang['WebServices_Page_down'] = 'Offline';
$pia_lang['WebServices_button_Delete_label'] = 'Elimina servizio';
$pia_lang['WebServices_button_Delete_Warning'] = 'Sei sicuro di voler eliminare questo servizio web?';
$pia_lang['WebServices_headline_NewService'] = 'Aggiungi nuovo servizio';
$pia_lang['WebServices_Events_all'] = 'Tutti gli eventi';
$pia_lang['WebServices_Events_down'] = 'Disattiva';
$pia_lang['WebServices_Events_none'] = 'niente';
$pia_lang['WebServices_BoxTitle_General'] = 'Generale';
$pia_lang['WebServices_Stats_Code'] = 'Stato delle pagine';
$pia_lang['WebServices_Stats_Time'] = 'Tempo di risposta';
$pia_lang['WebServices_Stats_Time_min'] = 'più veloce';
$pia_lang['WebServices_Stats_Time_max'] = 'più lento';
$pia_lang['WebServices_Stats_Location'] = 'Posizione';
$pia_lang['WebServices_Stats_IP'] = 'IP attuale';
$pia_lang['WebServices_Stats_IPLocation'] = 'Assegnazione del paese';
$pia_lang['WebServices_Stats_comment_a'] = '(Calcolato da tutti gli scansione di questo servizio)';

//////////////////////////////////////////////////////////////////
// WebServices Details Page - Backend
//////////////////////////////////////////////////////////////////

$pia_lang['BackWebServices_UpdServ'] = 'Il servizio web è stato aggiornato';
$pia_lang['BackWebServices_UpdServError'] = 'Il servizio web non è stato aggiornato';
$pia_lang['BackWebServices_InsServ'] = 'Il servizio web è stato salvato';
$pia_lang['BackWebServices_InsServError'] = 'Il servizio web non è stato salvato';
$pia_lang['BackWebServices_DelServ'] = 'Il servizio web è stato rimosso dal database';
$pia_lang['BackWebServices_DelServError'] = 'Il servizio web non è stato rimosso o è stato rimosso parzialmente';

//////////////////////////////////////////////////////////////////
// ICMP Monitoring Page
//////////////////////////////////////////////////////////////////

$pia_lang['ICMPMonitor_Title'] = 'Monitor ICMP';
$pia_lang['ICMPMonitor_headline_IP'] = 'Monitora un nuovo indirizzo IP';
$pia_lang['ICMPMonitor_label_IP'] = 'Indirizzo IP dell&apos;host';
$pia_lang['ICMPMonitor_label_Hostname'] = 'Nome host';
$pia_lang['ICMPMonitor_label_RTT'] = 'RTT medio';
$pia_lang['BackICMP_mon_disabled'] = 'Il monitoraggio ICMP è disabilitato';
$pia_lang['BackICMP_mon_enabled'] = 'Il monitoraggio ICMP è abilitato';
$pia_lang['BackICMP_mon_InsICMP'] = 'L&apos;host ICMP è stato salvato';
$pia_lang['BackICMP_mon_InsICMPError'] = 'L&apos;host ICMP non è stato salvato';
$pia_lang['BackICMP_mon_DelICMP'] = 'L&apos;host ICMP è stato rimosso dal database';
$pia_lang['BackICMP_mon_DelICMPError'] = 'L&apos;host ICMP non può essere rimosso o è stato rimosso parzialmente';
$pia_lang['BackICMP_mon_UpdICMP'] = 'L&apos;host ICMP è stato aggiornato';
$pia_lang['BackICMP_mon_UpdICMPError'] = 'L&apos;host ICMP non può essere aggiornato';
$pia_lang['ICMPMonitor_Shortcut_Online'] = 'Online';
$pia_lang['ICMPMonitor_Shortcut_Offline'] = 'Offline/Down';
$pia_lang['ICMPMonitor_Availability'] = 'Disponibilità';

//////////////////////////////////////////////////////////////////
// Maintenance Page
//////////////////////////////////////////////////////////////////

$pia_lang['Maintenance_Title'] = 'Impostazioni e Manutenzione';
$pia_lang['Maintenance_database_path'] = 'Percorso del Database';
$pia_lang['Maintenance_database_size'] = 'Dimensione del Database';
$pia_lang['Maintenance_database_lastmod'] = 'Ultimo aggiornamento (DB)';
$pia_lang['Maintenance_database_backup'] = 'Backup: DB';
$pia_lang['Maintenance_config_backup'] = 'Backup: Configurazione';
$pia_lang['Maintenance_database_backup_found'] = 'Backup disponibili';
$pia_lang['Maintenance_database_backup_total'] = 'Dimensione totale';
$pia_lang['Maintenance_arp_status'] = 'Stato della Scansione ARP';
$pia_lang['Maintenance_arp_status_off'] = 'Attualmente disattivato';
$pia_lang['Maintenance_arp_status_on'] = 'Scansione(i) attualmente attiva(e)';
$pia_lang['Maintenance_notification_config'] = 'Notifica (Dispositivi, ICMP)';
$pia_lang['Maintenance_notification_config_webmon'] = 'Notifica (Servizi)';
$pia_lang['Maintenance_Tools_Logviewer_Scan'] = 'Scansione';
$pia_lang['Maintenance_Tools_Logviewer_Scan_empty'] = 'Probabilmente una scansione è in corso';
$pia_lang['Maintenance_Tools_Logviewer_IPLog'] = 'Log IP Internet';
$pia_lang['Maintenance_Tools_Logviewer_IPLog_empty'] = 'Nessun log disponibile';
$pia_lang['Maintenance_Tools_Logviewer_Vendor'] = 'Aggiornamento Vendor';
$pia_lang['Maintenance_Tools_Logviewer_Vendor_empty'] = 'Nessun log disponibile';
$pia_lang['Maintenance_Tools_Logviewer_Cleanup'] = 'Pulizia';
$pia_lang['Maintenance_Tools_Logviewer_Cleanup_empty'] = 'Nessun log disponibile';
$pia_lang['Maintenance_Tools_Logviewer_Nmap'] = 'Nmap (Sessione)';
$pia_lang['Maintenance_Tools_Logviewer_Nmap_empty'] = 'Nessun log disponibile';
$pia_lang['Maintenance_Tools_Logviewer_WebServices'] = 'Servizi Web';
$pia_lang['Maintenance_Tools_Logviewer_WebServices_empty'] = 'Nessun log disponibile';
$pia_lang['Maintenance_Tools_Logviewer_WOL'] = 'Wake-on-LAN (Sessione)';
$pia_lang['Maintenance_Tools_Logviewer_WOL_empty'] = 'Nessun log disponibile';
$pia_lang['Maintenance_themeselector_lable'] = 'Seleziona Tema';
$pia_lang['Maintenance_themeselector_empty'] = 'Seleziona un Tema';
$pia_lang['Maintenance_themeselector_apply'] = 'Applica';
$pia_lang['Maintenance_lang_selector_lable'] = 'Seleziona Lingua';
$pia_lang['Maintenance_lang_selector_empty'] = 'Seleziona una Lingua';
$pia_lang['Maintenance_lang_en_us'] = 'Inglese (US)';
$pia_lang['Maintenance_lang_de_de'] = 'Tedesco (DE)';
$pia_lang['Maintenance_lang_es_es'] = 'Spagnolo (ES)';
$pia_lang['Maintenance_lang_fr_fr'] = 'Francese (FR)';
$pia_lang['Maintenance_lang_it_it'] = 'Italiano (IT)';
$pia_lang['Maintenance_lang_selector_apply'] = 'Applica';
$pia_lang['Maintenance_Tools_Tab_Settings'] = 'Impostazioni';
$pia_lang['Maintenance_Tools_Tab_Settings_Intro'] = 'Le opzioni elencate qui apportano modifiche alla configurazione lato server. Queste modifiche influiscono su tutti i dispositivi che accedono a questa pagina.';
$pia_lang['Maintenance_Tools_Tab_GUI'] = 'GUI';
$pia_lang['Maintenance_Tools_Tab_Tools'] = 'Manutenzione';
$pia_lang['Maintenance_Tools_Tab_BackupRestore'] = 'Backup';
$pia_lang['Maintenance_Tools_Tab_Subheadline_a'] = 'Generale';
$pia_lang['Maintenance_Tools_Tab_Subheadline_b'] = 'Configura la panoramica dei dispositivi';
$pia_lang['Maintenance_Tools_Tab_Subheadline_c'] = 'Sicurezza';
$pia_lang['Maintenance_Tools_Tab_Subheadline_d'] = 'Scans';
$pia_lang['Maintenance_Tools_Tab_Subheadline_e'] = 'FavIcon';
$pia_lang['Maintenance_Tools_Tab_Subheadline_e_Intro'] = 'Puoi inserire l&apos;URL del FavIcon desiderato nel campo, o scegliere tra FavIcons locali o remoti (https://github.com/leiweibau/Pi.Alert). A seconda della configurazione, i FavIcons locali potrebbero non funzionare come icona della schermata principale.';
$pia_lang['Maintenance_Tool_darkmode'] = 'Modalità Scuro';
$pia_lang['Maintenance_Tool_darkmode_noti'] = 'Cambio Modalità';
$pia_lang['Maintenance_Tool_darkmode_noti_text'] = 'Cambia tra la modalità chiara e quella scura. Se il cambio di modalità dovesse non funzionare correttamente, prova a cancellare la cache del browser.';
$pia_lang['Maintenance_Tool_onlinehistorygraph'] = 'Cronologia Attività';
$pia_lang['Maintenance_Tool_onlinehistorygraph_noti'] = 'Cronologia Attività';
$pia_lang['Maintenance_Tool_onlinehistorygraph_noti_text'] = 'Abilita o disabilita la cronologia delle attività sulla pagina dei dispositivi e di presenza.';
$pia_lang['Maintenance_Tool_webservicemon'] = 'Monitoraggio Servizi Web';
$pia_lang['Maintenance_Tool_webservicemon_noti'] = 'Monitoraggio Servizi Web';
$pia_lang['Maintenance_Tool_webservicemon_noti_text'] = 'Abilita o disabilita il monitoraggio dei servizi web per Pi.Alert. Con l&apos;attivazione, verranno visualizzati elementi aggiuntivi nell&apos;interfaccia. Con la disattivazione, questi elementi scompariranno nuovamente.';
$pia_lang['Maintenance_Tool_icmpmon'] = 'Monitoraggio ICMP';
$pia_lang['Maintenance_Tool_icmpmon_noti'] = 'Monitoraggio ICMP';
$pia_lang['Maintenance_Tool_icmpmon_noti_text'] = 'Abilita o disabilita il monitoraggio ICMP per Pi.Alert. Con l&apos;attivazione, verranno visualizzati elementi aggiuntivi nell&apos;interfaccia. Con la disattivazione, questi elementi scompariranno nuovamente.';
$pia_lang['Maintenance_Tool_mainscan'] = 'Scansione Principale';
$pia_lang['Maintenance_Tool_mainscan_noti'] = 'Scansione Principale';
$pia_lang['Maintenance_Tool_mainscan_noti_text'] = 'Abilita o disabilita la modalità di scansione principale per Pi.Alert (Arp-scan). La raccolta di dati dalle fonti esterne configurate rimane attiva.';
$pia_lang['Maintenance_Tool_DevListCol_noti'] = 'Configura la vista generale dei dispositivi';
$pia_lang['Maintenance_Tool_DevListCol_noti_text'] = 'Vuoi salvare le modifiche apportate? Questa modifica influirà su tutti i dispositivi che accedono a questa pagina.';
$pia_lang['Maintenance_Tool_setapikey_false'] = 'Nessuna API-Key impostata';
$pia_lang['Maintenance_Tool_setapikey'] = 'Imposta API-Key';
$pia_lang['Maintenance_Tool_setapikey_text'] = 'Con l&apos;API-Key è possibile effettuare interrogazioni al database senza utilizzare il sito web. Questo potrebbe essere necessario se un altro servizio o sito web deve accedere ai dati di questo database. Se esiste già un API-Key, verrà sovrascritto.';
$pia_lang['Maintenance_Tool_setapikey_noti'] = 'Imposta API-Key';
$pia_lang['Maintenance_Tool_setapikey_noti_text'] = 'Vuoi sostituire un eventuale API-Key esistente con una nuova chiave? Le chiavi esistenti non saranno più utilizzabili.';
$pia_lang['Maintenance_Tool_ignorelist'] = 'Lista Ignorata';
$pia_lang['Maintenance_Tool_ignorelist_false'] = 'Nessuna lista ignorata configurata';
$pia_lang['Maintenance_arpscantimer_empty'] = 'Imposta timer';
$pia_lang['Maintenance_Tool_arpscansw'] = 'Arp-scan attiva/disattiva';
$pia_lang['Maintenance_Tool_arpscansw_text'] = 'Attiva o disattiva tutti gli Arp-scan di Pi.Alert. Se il timer non è stato impostato durante l&apos;attivazione, Pi.Alert si riattiverà dopo una pausa di 10 minuti con la successiva scansione programmata. Le scansioni attualmente in corso non verranno interrotte.';
$pia_lang['Maintenance_Tool_arpscansw_noti'] = 'Attiva/Disattiva arp-scan';
$pia_lang['Maintenance_Tool_arpscansw_noti_text'] = 'Quando la scansione è disattivata, rimarrà disattivata fino a quando non verrà riattivata.';
$pia_lang['Maintenance_Tool_test_notification'] = 'Testa notifica';
$pia_lang['Maintenance_Tool_test_notification_text'] = 'Invia una notifica di prova per testare la configurazione corretta dei servizi.';
$pia_lang['Maintenance_Tool_test_notification_noti'] = 'Notifica di prova';
$pia_lang['Maintenance_Tool_test_notification_noti_text'] = 'Vuoi inviare una notifica di test tramite tutti i servizi di notifica configurati e attivati?';
$pia_lang['Maintenance_Tool_del_alldev'] = 'Cancella tutti i dispositivi';
$pia_lang['Maintenance_Tool_del_alldev_text'] = 'Tutti i dispositivi saranno rimossi dal database. Questa funzione non influisce sui dispositivi creati nella vista generale di rete.';
$pia_lang['Maintenance_Tool_del_alldev_noti'] = 'Cancella tutti i dispositivi';
$pia_lang['Maintenance_Tool_del_alldev_noti_text'] = 'Sei sicuro di voler cancellare tutti i dispositivi?';
$pia_lang['Maintenance_Tool_del_unknowndev'] = 'Cancella dispositivi (sconosciuti)';
$pia_lang['Maintenance_Tool_del_unknowndev_text'] = 'Tutti i dispositivi con nome (sconosciuto) verranno rimossi dal database.';
$pia_lang['Maintenance_Tool_del_unknowndev_noti'] = 'Cancella dispositivi (sconosciuti)';
$pia_lang['Maintenance_Tool_del_unknowndev_noti_text'] = 'Sei sicuro di voler cancellare tutti i dispositivi (sconosciuti) dal database?';
$pia_lang['Maintenance_Tool_del_allevents'] = 'Cancella tutti gli eventi';
$pia_lang['Maintenance_Tool_del_allevents_text'] = 'Tutti gli eventi verranno rimossi dal database. Ciò reimposta anche la presenza. Potrebbero verificarsi sessioni non valide da quel momento in poi. Effettuare una scansione mentre il dispositivo interessato è "online" dovrebbe risolvere il problema.';
$pia_lang['Maintenance_Tool_del_allevents_noti'] = 'Cancella tutti gli eventi';
$pia_lang['Maintenance_Tool_del_allevents_noti_text'] = 'Sei sicuro di voler cancellare tutti gli eventi dal database? Questo reimposta la presenza di tutti i dispositivi.';
$pia_lang['Maintenance_Tool_del_Inactive_Hosts'] = 'Cancella dispositivi inattivi';
$pia_lang['Maintenance_Tool_del_Inactive_Hosts_text'] = 'Verranno cancellati tutti i dispositivi inattivi da almeno 30 giorni. Gli eventi relativi a questi dispositivi verranno rimossi dal database.';
$pia_lang['Maintenance_Tool_backup'] = 'Backup del database';
$pia_lang['Maintenance_Tool_backup_text'] = 'I backup del database si trovano nella directory del database, compressi come archivi zip e denominati con la data di creazione. Non c&apos;è un limite massimo di backup.';
$pia_lang['Maintenance_Tool_backup_noti'] = 'Backup del database';
$pia_lang['Maintenance_Tool_backup_noti_text'] = 'Sei sicuro di voler eseguire ora il backup del database? Assicurati che non siano in corso scansioni.';
$pia_lang['Maintenance_Tool_backupcsv'] = 'Backup dispositivi/servizi su<br>File CSV';
$pia_lang['Maintenance_Tool_backupcsv_text'] = 'I dispositivi, i servizi web e i dispositivi dal monitoraggio ICMP saranno esportati su file CSV e salvati come archivi zip. Questo serve come soluzione di emergenza nel caso in cui tutto debba essere reinserito a causa di un database difettoso. Al momento l&apos;importazione non è possibile.';
$pia_lang['Maintenance_Tool_backupcsv_noti'] = 'Backup dispositivi/servizi su file CSV';
$pia_lang['Maintenance_Tool_backupcsv_noti_text'] = 'Sei sicuro di voler esportare le liste di dispositivi e servizi web come file CSV adesso?';
$pia_lang['Maintenance_Tool_restore'] = 'Ripristina database';
$pia_lang['Maintenance_Tool_restore_blocked'] = 'non disponibile';
$pia_lang['Maintenance_Tool_restore_text'] = 'L&apos;ultimo backup può essere ripristinato utilizzando questa funzione. Le versioni più vecchie devono essere ripristinate manualmente. Dopo il ripristino, è consigliabile verificare l&apos;integrità nel caso in cui il database fosse aperto durante il backup.';
$pia_lang['Maintenance_Tool_restore_noti'] = 'Ripristina database';
$pia_lang['Maintenance_Tool_restore_noti_text'] = 'Sei sicuro di voler ripristinare il database dall&apos;ultimo backup? Assicurati che non siano in corso scansioni.';
$pia_lang['Maintenance_Tool_latestdb_download'] = 'Scarica l&apos;ultimo backup del database';
$pia_lang['Maintenance_Tool_latestconf_download'] = 'Scarica la configurazione attuale di pialert.conf';
$pia_lang['Maintenance_Tool_CSVExport_download'] = 'Scarica l&apos;esportazione CSV';
$pia_lang['Maintenance_Tool_purgebackup'] = 'Pulisci i backup';
$pia_lang['Maintenance_Tool_purgebackup_text'] = 'Tutti i backup tranne gli ultimi 3 verranno cancellati. Questo riguarda sia i backup del database che quelli del file di configurazione.';
$pia_lang['Maintenance_Tool_purgebackup_noti'] = 'Pulisci i backup';
$pia_lang['Maintenance_Tool_purgebackup_noti_text'] = 'Sei sicuro di voler cancellare tutti i backup tranne gli ultimi 3?';
$pia_lang['Maintenance_Tool_del_ActHistory'] = 'Cancella la cronologia di attività di rete';
$pia_lang['Maintenance_Tool_del_ActHistory_text'] = 'Il grafico dell&apos;attività di rete verrà ripristinato, ma gli eventi non saranno influenzati.';
$pia_lang['Maintenance_Tool_del_ActHistory_noti'] = 'Cancella la cronologia di attività di rete';
$pia_lang['Maintenance_Tool_del_ActHistory_noti_text'] = 'Sei sicuro di voler ripristinare la cronologia di attività di rete?';
$pia_lang['Maintenance_Tool_loginenable'] = 'Abilita accesso';
$pia_lang['Maintenance_Tool_loginenable_text'] = 'Dopo l&apos;attivazione, verrai reindirizzato automaticamente alla pagina di accesso. Se non hai già impostato una password, la password predefinita è "123456".';
$pia_lang['Maintenance_Tool_loginenable_noti'] = 'Abilita accesso';
$pia_lang['Maintenance_Tool_loginenable_noti_text'] = 'Sei sicuro di voler abilitare l&apos;accesso?';
$pia_lang['Maintenance_Tool_logindisable'] = 'Disabilita accesso';
$pia_lang['Maintenance_Tool_logindisable_text'] = 'L&apos;accesso verrà disabilitato. Ogni utente avrà nuovamente accesso alla pagina di Pi.Alert.';
$pia_lang['Maintenance_Tool_logindisable_noti'] = 'Disabilita accesso';
$pia_lang['Maintenance_Tool_logindisable_noti_text'] = 'Sei sicuro di voler disabilitare l&apos;accesso?';
$pia_lang['Maintenance_ConfEditor_Start'] = 'Modifica configurazione Pi.Alert';
$pia_lang['Maintenance_ConfEditor_Hint'] = 'Note sull&apos;editor';
$pia_lang['Maintenance_ConfEditor_Backup'] = 'Crea backup';
$pia_lang['Maintenance_ConfEditor_Restore'] = 'Versione precedente';
$pia_lang['Maintenance_ConfEditor_Restore_noti'] = 'Versione precedente';
$pia_lang['Maintenance_ConfEditor_Restore_noti_text'] = 'Verrà ripristinata l&apos;ultima versione del file di configurazione. La "versione precedente" è o quella dell&apos;ultimo backup o quella precedente all&apos;ultimo salvataggio, a seconda di quale sia la più recente.';
$pia_lang['Maintenance_ConfEditor_Backup_info'] = 'Oltre al file "pialert-prev.bak", verrà creato un altro backup con la data corrente inclusa l&apos;ora. Questo backup deve essere ripristinato manualmente in caso di necessità (rinominandolo in "pialert.conf"). Un file "pialert-prev.bak" esistente verrà sovrascritto ad ogni backup.';
$pia_lang['Maintenance_ConfEditor_Restore_info'] = 'Questa funzione ripristina il file di configurazione dalla versione "pialert-prev.bak". Il file "pialert-prev.bak" viene creato sia quando si salva il file di configurazione che quando si crea un backup.';
$pia_lang['Maintenance_ConfEditor_Save_info'] = 'Il contenuto del campo di testo con eventuali modifiche verrà salvato nel file "pialert.conf". La configurazione precedente verrà salvata come "pialert-prev.bak". Ogni volta che si salva, il file "pialert-prev.bak" verrà sovrascritto con la versione precedente del file di configurazione.';
$pia_lang['Maintenance_Tool_ConfBackup'] = 'Crea backup della configurazione';
$pia_lang['Maintenance_Tool_ConfBackup_text'] = 'Oltre al file "pialert-prev.bak", verrà creato un altro backup con la data corrente inclusa l&apos;ora. Questo backup deve essere ripristinato manualmente in caso di necessità (rinominandolo in "pialert.conf").';
$pia_lang['FavIcon_color_white'] = 'white';
$pia_lang['FavIcon_color_black'] = 'black';
$pia_lang['FavIcon_color_red'] = 'red';
$pia_lang['FavIcon_color_blue'] = 'blue';
$pia_lang['FavIcon_color_green'] = 'green';
$pia_lang['FavIcon_color_yellow'] = 'yellow';
$pia_lang['FavIcon_color_purple'] = 'purple';
$pia_lang['FavIcon_logo_white'] = 'white Logo';
$pia_lang['FavIcon_logo_black'] = 'black Logo';
$pia_lang['FavIcon_mode_glass'] = 'glass';
$pia_lang['FavIcon_mode_flat'] = 'flat';
$pia_lang['FavIcon_local'] = 'local';
$pia_lang['FavIcon_remote'] = 'remote';

//////////////////////////////////////////////////////////////////
// Maintenance Page (Backend)
//////////////////////////////////////////////////////////////////

$pia_lang['BackDevices_Arpscan_disabled'] = 'Scansione ARP automatica disattivata.';
$pia_lang['BackDevices_Arpscan_enabled'] = 'Scansione ARP automatica abilitata';
$pia_lang['BackDevices_setapikey'] = 'Chiave API impostata';
$pia_lang['BackDevices_test_notification'] = 'Messaggio di test inviato';
$pia_lang['BackDevices_darkmode_disabled'] = 'Modalità scura disattivata';
$pia_lang['BackDevices_darkmode_enabled'] = 'Modalità scura abilitata';
$pia_lang['BackDevices_webservicemon_disabled'] = 'Monitoraggio del servizio web disattivato';
$pia_lang['BackDevices_webservicemon_enabled'] = 'Monitoraggio del servizio web abilitato';
$pia_lang['BackDevices_MainScan_disabled'] = 'Scansione principale disattivata';
$pia_lang['BackDevices_MainScan_enabled'] = 'Scansione principale abilitata';
$pia_lang['BackDevices_onlinehistorygraph_disabled'] = 'Cronologia dell&apos;attività online disattivata';
$pia_lang['BackDevices_onlinehistorygraph_enabled'] = 'Cronologia dell&apos;attività online abilitata';
$pia_lang['BackDevices_Restore_CopError'] = 'Impossibile copiare il database originale';
$pia_lang['BackDevices_Restore_okay'] = 'Ripristino eseguito con successo';
$pia_lang['BackDevices_Restore_Failed'] = 'Ripristino fallito. Effettuare il ripristino manuale del backup';
$pia_lang['BackDevices_Backup_WALError'] = 'Il database originale non è stato copiato a causa di possibili transazioni aperte.';
$pia_lang['BackDevices_Backup_IntegrityError'] = 'Il database copiato non ha superato il controllo di integrità.';
$pia_lang['BackDevices_Backup_CopError'] = 'Impossibile eseguire il backup del database originale';
$pia_lang['BackDevices_Backup_okay'] = 'Backup completato con successo';
$pia_lang['BackDevices_Backup_Failed'] = 'Backup parziale eseguito. L&apos;archivio è vuoto o non esiste';
$pia_lang['BackDevices_BackupCSV_FailedExport'] = 'Impossibile creare uno o più file CSV.';
$pia_lang['BackDevices_BackupCSV_FailedZip'] = 'Impossibile creare l&apos;archivio con i file CSV.';
$pia_lang['BackDevices_BackupCSV_okay'] = 'L&apos;archivio con i file CSV è stato creato con successo.';
$pia_lang['BackDevices_DBTools_DelDev_a'] = 'Dispositivo eliminato con successo';
$pia_lang['BackDevices_DBTools_DelDev_b'] = 'Dispositivi eliminati con successo';
$pia_lang['BackDevices_DBTools_DelEvents'] = 'Eventi eliminati con successo';
$pia_lang['BackDevices_DBTools_DelEventsError'] = 'Errore nell&apos;eliminazione degli eventi.';
$pia_lang['BackDevices_DBTools_DelDevError_a'] = 'Errore nell&apos;eliminazione del dispositivo.';
$pia_lang['BackDevices_DBTools_DelDevError_b'] = 'Errore nell&apos;eliminazione dei dispositivi.';
$pia_lang['BackDevices_DBTools_UpdDev'] = 'Dispositivo aggiornato con successo.';
$pia_lang['BackDevices_DBTools_UpdDevError'] = 'Errore nell&apos;aggiornamento del dispositivo.';
$pia_lang['BackDevices_DBTools_Purge'] = 'Eliminati i backup più vecchi.';
$pia_lang['BackDevices_DBTools_DelActHistory'] = 'Cronologia dell&apos;attività di rete ripristinata.';
$pia_lang['BackDevices_DBTools_DelActHistoryError'] = 'Errore nel ripristino della cronologia dell&apos;attività di rete.';
$pia_lang['BackDevices_DBTools_DelInactHosts'] = 'Host inattivi eliminati con successo.';
$pia_lang['BackDevices_DBTools_DelInactHostsError'] = 'Errore nell&apos;eliminazione degli host inattivi.';
$pia_lang['BackDevices_Login_disabled'] = 'Accesso disabilitato.';
$pia_lang['BackDevices_Login_enabled'] = 'Accesso abilitato.';
$pia_lang['BackDevices_Theme_set'] = 'Tema applicato.';
$pia_lang['BackDevices_Theme_notset'] = 'Tema non applicato.';
$pia_lang['BackDevices_Theme_invalid'] = 'Nessun tema selezionato.';
$pia_lang['BackDevices_Language_set'] = 'Lingua applicata.';
$pia_lang['BackDevices_Language_notset'] = 'Lingua non applicata.';
$pia_lang['BackDevices_Language_invalid'] = 'Nessuna lingua selezionata.';
$pia_lang['BackDevices_DevListCol_noti_text'] = 'Impostazioni tabella salvate.';
$pia_lang['BackDevices_ConfEditor_CopError'] = 'Impossibile effettuare il backup della configurazione.';
$pia_lang['BackDevices_ConfEditor_CopOkay'] = 'Backup della configurazione completato.';
$pia_lang['BackDevices_ConfEditor_RestoreError'] = 'Impossibile ripristinare la versione precedente della configurazione.';
$pia_lang['BackDevices_ConfEditor_RestoreOkay'] = 'Ripristino della versione precedente della configurazione completato.';
$pia_lang['BackDevices_Report_Delete'] = 'Notifica/e eliminata/e.';
$pia_lang['BackFiles_FavIcon_invalidURL'] = 'È stata inserita un URL non valida.';
$pia_lang['BackFiles_FavIcon_ErrorURL'] = 'Un FavIcon inserito manualmente deve essere un URL. I riferimenti al percorso per un file locale non verranno salvati.';
$pia_lang['BackFiles_FavIcon_okay'] = 'Il nuovo FavIcon è stato salvato.';

//////////////////////////////////////////////////////////////////
// Network Page
//////////////////////////////////////////////////////////////////

$pia_lang['Network_Title'] = 'Panoramica della Rete';
$pia_lang['Network_ManageDevices'] = 'Gestisci Dispositivi di Rete';
$pia_lang['Network_ManageAdd_Name'] = 'Nome del nuovo dispositivo';
$pia_lang['Network_ManageAdd_Name_text'] = 'Nome senza caratteri speciali';
$pia_lang['Network_ManageAdd_Type'] = 'Tipo di dispositivo';
$pia_lang['Network_ManageAdd_Type_text'] = '-- Seleziona il tipo --';
$pia_lang['Network_ManageAdd_Port'] = 'Numero di porta';
$pia_lang['Network_ManageAdd_Port_text'] = 'Lascia vuoto per WLAN o Powerline';
$pia_lang['Network_ManageAdd_Submit'] = 'Aggiungi dispositivo';
$pia_lang['Network_ManageEdit_ID'] = 'Seleziona dispositivo da modificare';
$pia_lang['Network_ManageEdit_ID_text'] = '-- Seleziona dispositivo --';
$pia_lang['Network_ManageEdit_Name'] = 'Nuovo nome';
$pia_lang['Network_ManageEdit_Name_text'] = 'Lascia vuoto se nessuna modifica';
$pia_lang['Network_ManageEdit_Type'] = 'Nuovo tipo';
$pia_lang['Network_ManageEdit_Type_text'] = '-- Seleziona il tipo --';
$pia_lang['Network_ManageEdit_Port'] = 'Nuovo numero di porta';
$pia_lang['Network_ManageEdit_Port_text'] = 'Lascia vuoto per WLAN o Powerline';
$pia_lang['Network_ManageEdit_Downlink'] = 'Configurazione manuale della porta (MAC di destinazione, porta locale)';
$pia_lang['Network_ManageEdit_Downlink_text'] = '0a:1b:3c:4d:5e:6f,16;MAC di destinazione 2,Porta 2;';
$pia_lang['Network_ManageEdit_Submit'] = 'Salva modifica';
$pia_lang['Network_ManageDel_Name'] = 'Seleziona dispositivo da eliminare';
$pia_lang['Network_ManageDel_Name_text'] = '-- Seleziona dispositivo --';
$pia_lang['Network_ManageDel_Submit'] = 'Elimina dispositivo';
$pia_lang['Network_Table_State'] = 'Stato';
$pia_lang['Network_Table_Hostname'] = 'Nome del dispositivo';
$pia_lang['Network_Table_IP'] = 'IP dell&apos;host';
$pia_lang['Network_UnassignedDevices'] = 'Dispositivi non assegnati';
$pia_lang['NetworkSettings_Title'] = 'Impostazioni Rete';
$pia_lang['Network_ManageDevices_Intro'] = 'Questa sezione serve per la creazione di dispositivi trasparenti senza IP (Unmanaged), come hub o switch, nonché dispositivi attivi come router, switch gestiti o access point,
											che influenzano la struttura di rete. Anche i dispositivi riconosciuti da Pi.Alert devono essere creati qui per la visualizzazione. La modifica o l&apos;eliminazione
											dei dispositivi già riconosciuti da Pi.Alert è indipendente dalla lista "<span class="text-maroon help_faq_code">' . $pia_lang['Navigation_Devices'] . '</span>" ed è pertanto
											applicabile solo alla pagina "<span class="text-maroon help_faq_code">' . $pia_lang['Navigation_Network'] . '</span>".';
$pia_lang['Network_Unmanaged_Devices'] = 'Gestisci Dispositivi Non Scansionabili';
$pia_lang['Network_Unmanaged_Devices_Intro'] = 'In questo punto è possibile creare dispositivi finali che occupano porte o connessioni su switch o router, ma non hanno funzionalità di rete.
											Inoltre, dispositivi che non possono essere riconosciuti ma che devono essere visualizzati per scopi di panoramica possono essere presi in considerazione qui.
											I dispositivi creati qui compaiono esclusivamente sulla pagina "<span class="text-maroon help_faq_code">' . $pia_lang['Navigation_Network'] . '</span>".';
$pia_lang['Network_Unmanaged_Devices_Connected'] = 'Connesso a';
$pia_lang['Network_Unmanaged_Devices_Connected_text'] = 'Seleziona dispositivo';
$pia_lang['Network_Unmanaged_Devices_Port'] = 'Sulla porta';
$pia_lang['Network_Unmanaged_Devices_Port_text'] = 'Sulla porta numero sull&apos;host selezionato';

//////////////////////////////////////////////////////////////////
// Reports Page
//////////////////////////////////////////////////////////////////

$pia_lang['Reports_Title'] = 'Notifiche';
$pia_lang['Reports_delete_all'] = 'Elimina tutte le notifiche';
$pia_lang['Reports_delete_all_noti'] = 'Elimina tutte le notifiche';
$pia_lang['Reports_delete_all_noti_text'] = 'Tutte le notifiche verranno eliminate. Il conteggio sarà reimpostato.';
$pia_lang['Reports_Rogue_hint'] = 'Una nuova segnalazione di un server DHCP sconosciuto verrà effettuata solo dopo l&apos;eliminazione di questa notifica.';

//////////////////////////////////////////////////////////////////
// UpdateCheck
//////////////////////////////////////////////////////////////////

$pia_lang['Maintenance_Tools_Updatecheck'] = 'Verifica aggiornamenti';
$pia_lang['Maintenance_Github_package_a'] = 'Ultima versione: ';
$pia_lang['Maintenance_Github_package_b'] = 'Ore';
$pia_lang['Updatecheck_Title'] = 'Controllo aggiornamenti';
$pia_lang['Updatecheck_cur'] = 'Versione corrente di Pi.Alert';
$pia_lang['Updatecheck_new'] = 'Ultima versione di Pi.Alert su Github';
$pia_lang['GeoLiteDB_Title'] = 'Controllo database GeoLite2';
$pia_lang['GeoLiteDB_cur'] = 'Database GeoLite2 attualmente caricato';
$pia_lang['GeoLiteDB_new'] = 'Ultimo database GeoLite2 su Github';
$pia_lang['Updatecheck_RN'] = 'Note sull&apos;aggiornamento di Pi.Alert';
$pia_lang['Updatecheck_RN2'] = 'Verifica aggiornamento di Pi.Alert';
$pia_lang['Updatecheck_U2D'] = 'Stai già utilizzando l&apos;ultima versione';
$pia_lang['GeoLiteDB_button_del'] = 'Elimina database GeoLite2';
$pia_lang['GeoLiteDB_button_ins'] = 'Installa database GeoLite2';
$pia_lang['GeoLiteDB_button_upd'] = 'Aggiorna database GeoLite2';
$pia_lang['GeoLiteDB_credits'] = 'Il database è scaricato da <a href="https://github.com/P3TERX/GeoLite.mmdb" target="_blank">github.com/P3TERX/GeoLite.mmdb</a>. Il database GeoLite2 è un prodotto di <a href="https://dev.maxmind.com/geoip/geolite2-free-geolocation-data" target="_blank">MaxMind</a>';
$pia_lang['GeoLiteDB_Installnotes'] = 'Puoi installare il database tramite la scheda ' . $pia_lang['WebServices_Tab_Graph'] . ' nella vista dettagli di qualsiasi servizio web.';
$pia_lang['GeoLiteDB_absent'] = 'Database non installato';

//////////////////////////////////////////////////////////////////
// System Info Page
//////////////////////////////////////////////////////////////////

$pia_lang['SysInfo_storage_note'] = 'È possibile che l&apos;utilizzo dello spazio su disco non possa essere determinato per tutti i dischi elencati sopra. Questo dipende dal modo in cui i dischi sono montati con l&apos;utente in uso.';

//////////////////////////////////////////////////////////////////
// Speedtest
//////////////////////////////////////////////////////////////////

$pia_lang['ookla_postinstall_note'] = 'Prima di poter utilizzare il client Speedtest di Ookla, è necessario eseguire il comando "sudo ./speedtest" una volta nella directory "$HOME/pialert/back/speedtest/." Il pulsante Speedtest verrà abilitato dopo il ricaricamento della pagina, ma funzionerà solo dopo aver accettato la licenza di Ookla.';
$pia_lang['ookla_devdetails_tab_title'] = 'Cronologia Speedtest';
$pia_lang['ookla_devdetails_required'] = 'Attualmente, la cronologia dei risultati di Speedtest è supportata solo con il Speedtest ufficiale di Ookla (<a href="https://www.speedtest.net/apps/cli" target="blank">speedtest.net</a>).';
$pia_lang['ookla_devdetails_tab_headline'] = 'Cronologia Speedtest';
$pia_lang['ookla_devdetails_table_time'] = 'Data';
$pia_lang['ookla_devdetails_table_isp'] = 'ISP';
$pia_lang['ookla_devdetails_table_server'] = 'Server';
$pia_lang['ookla_devdetails_table_ping'] = 'Ping';
$pia_lang['ookla_devdetails_table_down'] = 'Download';
$pia_lang['ookla_devdetails_table_up'] = 'Upload';

// =============================================================================================================
$pia_journ_lang['Journal_TableHead_Class'] = 'Classe';
$pia_journ_lang['Journal_TableHead_Trigger'] = 'Trigger';

$pia_journ_lang['Title'] = 'Registro Applicazioni';
$pia_journ_lang['File_hash'] = 'Hash di pialert.conf';
// Frontend
$pia_journ_lang['a_000'] = 'File di configurazione';
$pia_journ_lang['a_001'] = 'Accesso alla GUI';
$pia_journ_lang['a_002'] = 'Scansioni Pi.Alert';
$pia_journ_lang['a_005'] = 'Configurazione GUI';
$pia_journ_lang['a_010'] = 'Manutenzione DB';
$pia_journ_lang['a_020'] = 'Dispositivi';
$pia_journ_lang['a_021'] = 'Multi-Editor';
$pia_journ_lang['a_025'] = 'Strumenti';
$pia_journ_lang['a_030'] = 'Monitoraggio del Web Service';
$pia_journ_lang['a_031'] = 'Monitoraggio ICMP';
$pia_journ_lang['a_032'] = 'Scansione principale';
$pia_journ_lang['a_040'] = 'Panoramica della Rete';
$pia_journ_lang['a_050'] = 'Report';
$pia_journ_lang['a_060'] = 'Controllo Aggiornamenti';
$pia_journ_lang['a_070'] = 'API';
// pialert-cli
$pia_journ_lang['b_002'] = $pia_journ_lang['a_002'];
$pia_journ_lang['b_010'] = 'Manutenzione DB';
$pia_journ_lang['b_030'] = $pia_journ_lang['a_030'];
$pia_journ_lang['b_031'] = $pia_journ_lang['a_031'];
$pia_journ_lang['b_032'] = $pia_journ_lang['a_032'];
// cronjob
$pia_journ_lang['c_002'] = $pia_journ_lang['a_002'];
$pia_journ_lang['c_010'] = $pia_journ_lang['a_010'];
// LogStrings
$pia_journ_lang['LogStr_0001'] = 'Aggiunta voce';
$pia_journ_lang['LogStr_0002'] = 'Voce modificata';
$pia_journ_lang['LogStr_0003'] = 'Voce eliminata';
$pia_journ_lang['LogStr_0004'] = 'Voce modificata (con errore)';
$pia_journ_lang['LogStr_0005'] = 'Voce eliminata (con errore)';
$pia_journ_lang['LogStr_0006'] = 'Ripristinato l&apos;ultimo cambio del file di configurazione';
$pia_journ_lang['LogStr_0007'] = 'Creato backup della configurazione';
$pia_journ_lang['LogStr_0008'] = 'Installato database GeoLite2';
$pia_journ_lang['LogStr_0009'] = 'Eliminato database GeoLite2';
$pia_journ_lang['LogStr_0010'] = 'Aggiornato database';
$pia_journ_lang['LogStr_0011'] = 'Creato backup del database';
$pia_journ_lang['LogStr_0012'] = 'Ripristinato backup del database';
$pia_journ_lang['LogStr_0013'] = 'Pulizia dei backup (file di configurazione e database)';
$pia_journ_lang['LogStr_0014'] = 'Eliminati host inattivi (con errore)';
$pia_journ_lang['LogStr_0015'] = 'Eliminati host inattivi';
$pia_journ_lang['LogStr_0016'] = 'Eliminati tutti gli host senza indirizzo MAC';
$pia_journ_lang['LogStr_0017'] = 'Eliminati tutti gli host senza indirizzo MAC (con errore)';
$pia_journ_lang['LogStr_0018'] = 'Eliminati tutti gli host (sconosciuti)';
$pia_journ_lang['LogStr_0019'] = 'Eliminati tutti gli host (sconosciuti) (con errore)';
$pia_journ_lang['LogStr_0020'] = 'Eliminati tutti gli eventi di un dispositivo';
$pia_journ_lang['LogStr_0021'] = 'Eliminati tutti gli eventi di un dispositivo (con errore)';
$pia_journ_lang['LogStr_0022'] = 'Eliminati tutti gli host dalla lista dei dispositivi';
$pia_journ_lang['LogStr_0023'] = 'Eliminati tutti gli host dalla lista dei dispositivi (con errore)';
$pia_journ_lang['LogStr_0024'] = 'Eliminati tutti gli eventi';
$pia_journ_lang['LogStr_0025'] = 'Eliminati tutti gli eventi (con errore)';
$pia_journ_lang['LogStr_0026'] = 'Reimpostata l&apos;attività di rete';
$pia_journ_lang['LogStr_0027'] = 'Reimpostata l&apos;attività di rete (con errore)';
$pia_journ_lang['LogStr_0030'] = 'Aggiunto componente di rete attivo (switch, router, ecc.)';
$pia_journ_lang['LogStr_0031'] = 'Modificato componente di rete attivo (switch, router, ecc.)';
$pia_journ_lang['LogStr_0032'] = 'Eliminato componente di rete attivo (switch, router, ecc.)';
$pia_journ_lang['LogStr_0033'] = 'Aggiunto dispositivo non scansionabile (hub, dispositivi PoE, Docker, ecc.)';
$pia_journ_lang['LogStr_0034'] = 'Modificato dispositivo non scansionabile (hub, dispositivi PoE, Docker, ecc.)';
$pia_journ_lang['LogStr_0035'] = 'Eliminato dispositivo non scansionabile (hub, dispositivi PoE, Docker, ecc.)';
$pia_journ_lang['LogStr_0036'] = 'Dispositivi, servizi web e host ICMP esportati in formato CSV.';
$pia_journ_lang['LogStr_0050'] = 'Attivata protezione password di Pi.Alert';
$pia_journ_lang['LogStr_0051'] = 'Disattivata protezione password di Pi.Alert';
$pia_journ_lang['LogStr_0052'] = 'Modificata configurazione delle colonne della lista dei dispositivi';
$pia_journ_lang['LogStr_0053'] = 'Cambiato tema';
$pia_journ_lang['LogStr_0054'] = 'Cambiata lingua';
$pia_journ_lang['LogStr_0055'] = $pia_lang['BackDevices_darkmode_disabled'];
$pia_journ_lang['LogStr_0056'] = $pia_lang['BackDevices_darkmode_enabled'];
$pia_journ_lang['LogStr_0057'] = $pia_lang['BackDevices_onlinehistorygraph_disabled'];
$pia_journ_lang['LogStr_0058'] = $pia_lang['BackDevices_onlinehistorygraph_enabled'];
$pia_journ_lang['LogStr_0059'] = 'FavIcon changed';
$pia_journ_lang['LogStr_0061'] = 'Aggiornamento Pi.Alert disponibile';
$pia_journ_lang['LogStr_0062'] = 'Nessun aggiornamento Pi.Alert disponibile';
$pia_journ_lang['LogStr_0063'] = 'Aggiornamento GeoLite2 DB disponibile';
$pia_journ_lang['LogStr_0064'] = 'Nessun aggiornamento GeoLite2 DB disponibile';
$pia_journ_lang['LogStr_0065'] = 'GeoLite2 DB non installato';
$pia_journ_lang['LogStr_0101'] = 'Ottimizzazione e pulizia del database';
$pia_journ_lang['LogStr_0210'] = 'Scansione nmap personalizzata eseguita';
$pia_journ_lang['LogStr_0251'] = 'Eseguito Wake-on-lan';
$pia_journ_lang['LogStr_0255'] = 'Eseguito Speedtest online';
$pia_journ_lang['LogStr_0301'] = $pia_lang['BackDevices_webservicemon_enabled'];
$pia_journ_lang['LogStr_0302'] = $pia_lang['BackDevices_webservicemon_disabled'];
$pia_journ_lang['LogStr_0303'] = $pia_lang['BackICMP_mon_enabled'];
$pia_journ_lang['LogStr_0304'] = $pia_lang['BackICMP_mon_disabled'];
$pia_journ_lang['LogStr_0500'] = 'Notifiche di test inviate';
$pia_journ_lang['LogStr_0503'] = 'Report eliminato';
$pia_journ_lang['LogStr_0504'] = 'Eliminati tutti i report';
$pia_journ_lang['LogStr_0510'] = 'Riattivato Pi.Alert';
$pia_journ_lang['LogStr_0511'] = 'Disattivato Pi.Alert (con orario)';
$pia_journ_lang['LogStr_0512'] = 'Disattivato Pi.Alert (per 10 minuti)';
$pia_journ_lang['LogStr_0513'] = 'Riattivato automaticamente Pi.Alert';
$pia_journ_lang['LogStr_0700'] = 'Impostata chiave API';
$pia_journ_lang['LogStr_9001'] = 'Accesso all&apos;interfaccia web avviato';
$pia_journ_lang['LogStr_9002'] = 'Disconnesso';
$pia_journ_lang['LogStr_9003'] = 'Errore nell&apos;accesso (password errata!)';
$pia_journ_lang['LogStr_9004'] = 'Accesso all&apos;interfaccia web avviato (con cookie)';
$pia_journ_lang['LogStr_9991'] = $pia_lang['BackDevices_MainScan_enabled'];
$pia_journ_lang['LogStr_9992'] = $pia_lang['BackDevices_MainScan_disabled'];
$pia_journ_lang['LogStr_9999'] = 'Modificato il file di configurazione';

?>