<?php
unset($pia_lang);
//////////////////////////////////////////////////////////////////
// About - Update by @TeroRERO 07ago2022
//////////////////////////////////////////////////////////////////
$pia_lang['About_Title'] = 'Open Source Network Guard';
$pia_lang['About_Exit'] = 'Abmelden';
$pia_lang['About_Reports'] = 'Meldungen zeigen';

//////////////////////////////////////////////////////////////////
// General
//////////////////////////////////////////////////////////////////
$pia_lang['Gen_Delete'] = 'Löschen';
$pia_lang['Gen_Cancel'] = 'Abbrechen';
$pia_lang['Gen_Okay'] = 'Ok';
$pia_lang['Gen_Purge'] = 'Aufräumen';
$pia_lang['Gen_Backup'] = 'Sichern';
$pia_lang['Gen_Restore'] = 'Wiederherstellen';
$pia_lang['Gen_Switch'] = 'Umschalten';
$pia_lang['Gen_Run'] = 'Ausführen';
$pia_lang['Gen_Save'] = 'Speichern';
$pia_lang['Gen_Close'] = 'Schließen';
$pia_lang['Gen_on'] = 'An';
$pia_lang['Gen_off'] = 'Aus';

//////////////////////////////////////////////////////////////////
// Login Page
//////////////////////////////////////////////////////////////////

$pia_lang['Login_Box'] = 'Passwort eingeben';
$pia_lang['Login_Remember'] = 'Passwort speichern';
$pia_lang['Login_Remember_small'] = '(für 7 Tage gültig)';
$pia_lang['Login_Submit'] = 'Anmelden';
$pia_lang['Login_Psw_run'] = 'Um das Passwort zu ändern nutze:';
$pia_lang['Login_Psw_new'] = 'dein_Passwort';
$pia_lang['Login_Psw_folder'] = 'im Ordner "~/pialert/back"';
$pia_lang['Login_Psw_alert'] = 'Sicherheitshinweis!';
$pia_lang['Login_Psw-box'] = 'Passwort';
$pia_lang['Login_Toggle_Info'] = 'Passwort Informationen';
$pia_lang['Login_Toggle_Info_headline'] = 'Passwort Information';
$pia_lang['Login_Toggle_Alert_headline'] = 'Passwort Warnung!';

//////////////////////////////////////////////////////////////////
// Sidebar
//////////////////////////////////////////////////////////////////

$pia_lang['Navigation_Devices'] = 'Geräte';
$pia_lang['Navigation_Services'] = 'Web Services';
$pia_lang['Navigation_Presence'] = 'Anwesenheit';
$pia_lang['Navigation_Events'] = 'Ereignisse';
$pia_lang['Navigation_Journal'] = 'Pi.Alert Journal';
$pia_lang['Navigation_Events_Dev'] = 'Geräte';
$pia_lang['Navigation_Events_Serv'] = 'Web Services';
$pia_lang['Navigation_ICMPScan'] = 'ICMP Monitoring';
$pia_lang['Navigation_Maintenance'] = 'Einstellungen';
$pia_lang['Navigation_Network'] = 'Netzwerk';
$pia_lang['Navigation_HelpFAQ'] = 'Hilfe / FAQ';
$pia_lang['Navigation_UpdateCheck'] = 'Update Check';
$pia_lang['Navigation_Section_A'] = 'HAUPTFUNKTIONEN';
$pia_lang['Navigation_Section_B'] = 'EVENTS & JOURNAL';
$pia_lang['Navigation_Section_C'] = 'EINSTELLUNGEN & HILFE';

//////////////////////////////////////////////////////////////////
// Device Page
//////////////////////////////////////////////////////////////////

$pia_lang['Device_Title'] = 'Geräte';
$pia_lang['Device_Shortcut_AllDevices'] = 'Alle Geräte';
$pia_lang['Device_Shortcut_Connected'] = 'Verbunden';
$pia_lang['Device_Shortcut_Favorites'] = 'Favoriten';
$pia_lang['Device_Shortcut_NewDevices'] = 'Neue Geräte';
$pia_lang['Device_Shortcut_DownAlerts'] = 'Down Meldungen';
$pia_lang['Device_Shortcut_Archived'] = 'Archiviert';
$pia_lang['Device_Shortcut_Devices'] = 'Geräte';
$pia_lang['Device_Shortcut_OnlineChart_a'] = 'Netzwerkaktivität über die letzten ';
$pia_lang['Device_Shortcut_OnlineChart_b'] = 'Stunden';
$pia_lang['Device_TableHead_Name'] = 'Name';
$pia_lang['Device_TableHead_Owner'] = 'Eigentümer';
$pia_lang['Device_TableHead_Type'] = 'Geräte&nbsp;Typ';
$pia_lang['Device_TableHead_Favorite'] = 'Favorit';
$pia_lang['Device_TableHead_Group'] = 'Gruppe';
$pia_lang['Device_TableHead_Location'] = 'Standort';
$pia_lang['Device_TableHead_FirstSession'] = 'Erste Sitzg.';
$pia_lang['Device_TableHead_LastSession'] = 'Letzte Sitzg.';
$pia_lang['Device_TableHead_LastIP'] = 'Letzte IP';
$pia_lang['Device_TableHead_MAC'] = 'MAC';
$pia_lang['Device_TableHead_MACaddress'] = 'MAC-Adresse';
$pia_lang['Device_TableHead_LastIPOrder'] = 'Last IP Order';
$pia_lang['Device_TableHead_Rowid'] = 'Zeilennummer';
$pia_lang['Device_TableHead_Status'] = 'Status';
$pia_lang['Device_TableHead_ConnectionType'] = 'Verbindungstyp';
$pia_lang['Device_Searchbox'] = 'Suche';
$pia_lang['Device_Tablelenght'] = 'Zeige _MENU_ Einträge';
$pia_lang['Device_Tablelenght_all'] = 'Alle';
$pia_lang['Device_Table_info'] = 'Zeige _START_ bis _END_ von _TOTAL_ Einträgen';
$pia_lang['Device_Table_nav_next'] = 'Nächste';
$pia_lang['Device_Table_nav_prev'] = 'Zurück';
$pia_lang['Device_bulkEditor_mode'] = 'Multi-Editor';
$pia_lang['Device_bulkEditor_mode_quit'] = 'Editor beenden';
$pia_lang['Device_bulkEditor_selectall'] = 'Alle auswählen';
$pia_lang['Device_bulkEditor_selectnone'] = 'Alle abwählen';
$pia_lang['Device_bulkEditor_savebox_title'] = 'Felder wurden gespeichert';
$pia_lang['Device_bulkEditor_savebox_noselection'] = 'Es wurde keine Felder zur Änderung ausgewählt';
$pia_lang['Device_bulkEditor_savebox_mod_devices'] = 'Geänderte Geräte';
$pia_lang['Device_bulkEditor_savebox_mod_fields'] = 'Geänderte Werte';
$pia_lang['Device_bulkEditor_hostbox_title'] = 'Wähle die zu bearbeitenden Geräte aus';
$pia_lang['Device_bulkEditor_inputbox_title'] = 'Felder bearbeiten';
$pia_lang['Device_bulkDel_button'] = 'GERÄTE LÖSCHEN';
$pia_lang['Device_bulkDel_info_head'] = 'Mehrere Geräte löschen';
$pia_lang['Device_bulkDel_info_text'] = 'Mit dieser Funktion löschst du eines oder mehrere Geräte aus der Datenbank. Wenn sich die Geräte noch im Netzwerk befinden, werden diese, unter Umständen, wieder in die Datenbank aufgenommen, jedoch ohne die individuellen Einstellungen.';
$pia_lang['Device_bulkDel_back_before'] = 'Geräteanzahl vorher';
$pia_lang['Device_bulkDel_back_after'] = 'Geräteanzahl aktuell';
$pia_lang['Device_bulkDel_back_hosts'] = 'Zu löschende MAC-Adressen';

//////////////////////////////////////////////////////////////////
// Presence Page
//////////////////////////////////////////////////////////////////

$pia_lang['Presence_Title'] = 'Anwesenheit pro Gerät';
$pia_lang['Presence_Shortcut_AllDevices'] = 'Alle Geräte';
$pia_lang['Presence_Shortcut_Connected'] = 'Verbunden';
$pia_lang['Presence_Shortcut_Favorites'] = 'Favoriten';
$pia_lang['Presence_Shortcut_NewDevices'] = 'Neue Geräte';
$pia_lang['Presence_Shortcut_DownAlerts'] = 'Down Meldungen';
$pia_lang['Presence_Shortcut_Archived'] = 'Archiviert';
$pia_lang['Presence_Shortcut_Devices'] = 'Geräte';

// Localizationfiles under pialert/front/lib/AdminLTE/bower_components/fullcalendar/dist/locale
$pia_lang['Presence_CallHead_Devices'] = 'Geräte';
$pia_lang['Presence_CalHead_lang'] = 'de';
$pia_lang['Presence_CalHead_year'] = 'Jahr';
$pia_lang['Presence_CalHead_quarter'] = 'Quartal';
$pia_lang['Presence_CalHead_month'] = 'Mon.';
$pia_lang['Presence_CalHead_week'] = 'Wo.';
$pia_lang['Presence_CalHead_day'] = 'Tag';

//////////////////////////////////////////////////////////////////
// Events Page
//////////////////////////////////////////////////////////////////

$pia_lang['Events_Title'] = 'Geräte - Ereignisse';
$pia_lang['Events_Periodselect_today'] = 'Heute';
$pia_lang['Events_Periodselect_LastWeek'] = 'Letzte Woche';
$pia_lang['Events_Periodselect_LastMonth'] = 'Letzter Monat';
$pia_lang['Events_Periodselect_LastYear'] = 'Letztes Jahr';
$pia_lang['Events_Periodselect_All'] = 'Alle Ereignisse';
$pia_lang['Events_Shortcut_AllEvents'] = 'Alle Ereignisse';
$pia_lang['Events_Shortcut_Sessions'] = 'Sitzungen';
$pia_lang['Events_Shortcut_MissSessions'] = 'fehlende Sitzungen';
$pia_lang['Events_Shortcut_VoidSessions'] = 'beendete Sitzungen';
$pia_lang['Events_Shortcut_NewDevices'] = 'Neue Geräte';
$pia_lang['Events_Shortcut_DownAlerts'] = 'Down Meldungen';
$pia_lang['Events_Shortcut_Events'] = 'Ereignisse';
$pia_lang['Events_TableHead_Order'] = 'Order';
$pia_lang['Events_TableHead_Device'] = 'Gerät';
$pia_lang['Events_TableHead_Owner'] = 'Eigentümer';
$pia_lang['Events_TableHead_Date'] = 'Datum';
$pia_lang['Events_TableHead_EventType'] = 'Ereignis Typ';
$pia_lang['Events_TableHead_Connection'] = 'Verbindung';
$pia_lang['Events_TableHead_Disconnection'] = 'Trennung';
$pia_lang['Events_TableHead_Duration'] = 'Dauer';
$pia_lang['Events_TableHead_DurationOrder'] = 'Duration Order';
$pia_lang['Events_TableHead_IP'] = 'IP';
$pia_lang['Events_TableHead_IPOrder'] = 'IP Order';
$pia_lang['Events_TableHead_AdditionalInfo'] = 'Zusätzliche Info';
$pia_lang['Events_Searchbox'] = 'Suche';
$pia_lang['Events_Tablelenght'] = 'Zeige _MENU_ Einträge';
$pia_lang['Events_Tablelenght_all'] = 'Alle';
$pia_lang['Events_Table_info'] = 'Zeige _START_ bis _END_ von _TOTAL_ Einträgen';
$pia_lang['Events_Table_nav_next'] = 'Nächste';
$pia_lang['Events_Table_nav_prev'] = 'Zurück';

//////////////////////////////////////////////////////////////////
// WebServices Events Page
//////////////////////////////////////////////////////////////////

$pia_lang['WebServices_Events_Title'] = 'Web Services - Ereignisse';
$pia_lang['WebServices_Events_Shortcut_All'] = 'Alle Ereignisse';
$pia_lang['WebServices_Events_Shortcut_HTTP2xx'] = 'HTTP Code 2xx';
$pia_lang['WebServices_Events_Shortcut_HTTP3xx'] = 'HTTP Code 3xx';
$pia_lang['WebServices_Events_Shortcut_HTTP4xx'] = 'HTTP Code 4xx';
$pia_lang['WebServices_Events_Shortcut_HTTP5xx'] = 'HTTP Code 5xx';
$pia_lang['WebServices_Events_Shortcut_Down'] = 'Down';
$pia_lang['WebServices_Events_TableHead_URL'] = 'Web Service URL';
$pia_lang['WebServices_Events_TableHead_TargetIP'] = 'Ziel IP';
$pia_lang['WebServices_Events_TableHead_ScanTime'] = 'Datum';
$pia_lang['WebServices_Events_TableHead_StatusCode'] = 'HTTP Status';
$pia_lang['WebServices_Events_TableHead_ResponsTime'] = 'Antwortzeit';

//////////////////////////////////////////////////////////////////
// Device Details Page
//////////////////////////////////////////////////////////////////

$pia_lang['DevDetail_Periodselect_today'] = 'Heute';
$pia_lang['DevDetail_Periodselect_LastWeek'] = 'Letzte Woche';
$pia_lang['DevDetail_Periodselect_LastMonth'] = 'Letzter Monat';
$pia_lang['DevDetail_Periodselect_LastYear'] = 'Letztes Jahr';
$pia_lang['DevDetail_Periodselect_All'] = 'Alle Infos';
$pia_lang['DevDetail_Shortcut_CurrentStatus'] = 'aktueller Status';
$pia_lang['DevDetail_Shortcut_Sessions'] = 'Sitzungen';
$pia_lang['DevDetail_Shortcut_Presence'] = 'Anwesenheit';
$pia_lang['DevDetail_Shortcut_DownAlerts'] = 'Down Meldungen';
$pia_lang['DevDetail_Tab_Details'] = 'Details';
$pia_lang['DevDetail_Tab_Nmap'] = 'Tools';
$pia_lang['DevDetail_Tab_Sessions'] = 'Sitzungen';
$pia_lang['DevDetail_Tab_Presence'] = 'Anwesenheit';
$pia_lang['DevDetail_Tab_Events'] = 'Ereignisse';
$pia_lang['DevDetail_MainInfo_Title'] = 'Haupt Infos';
$pia_lang['DevDetail_MainInfo_mac'] = 'MAC';
$pia_lang['DevDetail_MainInfo_Name'] = 'Name';
$pia_lang['DevDetail_MainInfo_Owner'] = 'Eigen&shy;tümer';
$pia_lang['DevDetail_MainInfo_Type'] = 'Typ';
$pia_lang['DevDetail_MainInfo_Vendor'] = 'Hersteller';
$pia_lang['DevDetail_MainInfo_Model'] = 'Modell';
$pia_lang['DevDetail_MainInfo_Serialnumber'] = 'Serien&nbsp;Nr.';
$pia_lang['DevDetail_MainInfo_Favorite'] = 'Favorit';
$pia_lang['DevDetail_MainInfo_Group'] = 'Gruppe';
$pia_lang['DevDetail_MainInfo_Location'] = 'Standort';
$pia_lang['DevDetail_MainInfo_Comments'] = 'Notiz';
$pia_lang['DevDetail_MainInfo_Network'] = 'Uplink Ziel';
$pia_lang['DevDetail_MainInfo_Network_Port'] = 'Ziel Portnummer';
$pia_lang['DevDetail_MainInfo_Network_ConnectType'] = 'Verbindungstyp';
$pia_lang['DevDetail_SessionInfo_Title'] = 'Sitzungsinfos';
$pia_lang['DevDetail_SessionInfo_Status'] = 'Status';
$pia_lang['DevDetail_SessionInfo_FirstSession'] = 'Erste Sitzung';
$pia_lang['DevDetail_SessionInfo_LastSession'] = 'Letzte Sitzung';
$pia_lang['DevDetail_SessionInfo_LastIP'] = 'Letzte IP';
$pia_lang['DevDetail_SessionInfo_StaticIP'] = 'Statische IP';
$pia_lang['DevDetail_Network_Titel'] = 'Netzwerk';
$pia_lang['DevDetail_EveandAl_Title'] = 'Ereignisse & Alarme einstellen';
$pia_lang['DevDetail_EveandAl_ScanCycle'] = 'Scan Abstand';
$pia_lang['DevDetail_EveandAl_AlertAllEvents'] = 'Melde alle Ereignisse';
$pia_lang['DevDetail_EveandAl_AlertDown'] = 'Melde Down';
$pia_lang['DevDetail_EveandAl_Skip'] = 'pausiere wiederhol. Meldungen für';
$pia_lang['DevDetail_EveandAl_NewDevice'] = 'Neues Gerät';
$pia_lang['DevDetail_EveandAl_Archived'] = 'Archivierung';
$pia_lang['DevDetail_EveandAl_RandomMAC'] = 'Zufällige MAC';
$pia_lang['DevDetail_EveandAl_ScanCycle_a'] = 'Gerät scannen (1 min)';
$pia_lang['DevDetail_EveandAl_ScanCycle_z'] = 'Gerät nicht scannen (0 min)';
$pia_lang['DevDetail_button_Delete'] = 'Gerät löschen';
$pia_lang['DevDetail_button_Delete_Warning'] = 'Sind Sie sicher, dass Sie dieses Gerät löschen wollen?';
$pia_lang['DevDetail_button_Reset'] = 'Abbruch';
$pia_lang['DevDetail_button_Save'] = 'Speichern';
$pia_lang['DevDetail_button_DeleteEvents'] = 'Events löschen';
$pia_lang['DevDetail_button_DeleteEvents_Warning'] = 'Sind Sie sicher, dass Sie alle Ereignisse dieses Geräts löschen möchten? (dies löscht den Ereignisverlauf und die Sitzungen und könnte bei ständigen (anhaltenden) Benachrichtigungen helfen)';
$pia_lang['DevDetail_SessionTable_Order'] = 'Order';
$pia_lang['DevDetail_SessionTable_Connection'] = 'Verbindung';
$pia_lang['DevDetail_SessionTable_Disconnection'] = 'Trennung';
$pia_lang['DevDetail_SessionTable_Duration'] = 'Dauer';
$pia_lang['DevDetail_SessionTable_IP'] = 'IP';
$pia_lang['DevDetail_SessionTable_Additionalinfo'] = 'Zusätzliche Info';
$pia_lang['DevDetail_Events_CheckBox'] = 'Blende Verbindungs-Ereignisse aus';
$pia_lang['DevDetail_Tools_nmap_buttonFast'] = 'Schneller Scan';
$pia_lang['DevDetail_Tools_nmap_buttonDefault'] = 'Standard Scan';
$pia_lang['DevDetail_Tools_nmap_buttonDetail'] = 'Detailierter Scan';
$pia_lang['DevDetail_Tools_nmap_buttonFast_text'] = 'Schneller Scan: Überprüft nur die wichtigsten 100 Ports (wenige Sekunden)';
$pia_lang['DevDetail_Tools_nmap_buttonDefault_text'] = 'Standard Scan: Nmap scannt die ersten 1.000 Ports für jedes angeforderte Scan-Protokoll. Damit werden etwa 93% der TCP-Ports und 49% der UDP-Ports erfasst. (ca. 5-10 Sekunden)';
$pia_lang['DevDetail_Tools_nmap_buttonDetail_text'] = 'Detailierter Scan: Standardscan mit aktivierter Betriebssystemerkennung, Versionserkennung, Skript-Scan und Traceroute (bis zu 30 oder mehr Sekunden)';
$pia_lang['DevDetail_Tools_WOL'] = 'Sende Wol Befehl an ';
$pia_lang['DevDetail_Tools_WOL_noti'] = 'Wake-on-LAN';
$pia_lang['DevDetail_Tools_WOL_noti_text'] = 'Das Wake-on-LAN Kommando wird an die Broadcast Adresse gesendet. Wenn das Ziel nicht in dem Subnet/vlan von Pi.Alert ist, wird das Ziel-Gerät nicht reagieren.';
$pia_lang['BackDevDetail_Tools_WOL_okay'] = 'Das Kommando wurde ausgeführt';
$pia_lang['BackDevDetail_Tools_WOL_error'] = 'Das Kommando wurde nicht ausgeführt';

//////////////////////////////////////////////////////////////////
// WebServices Details Page
//////////////////////////////////////////////////////////////////

$pia_lang['WebServices_Title'] = 'Web Services';
$pia_lang['WebServices_unknown_Device'] = 'Unbekanntes Gerät';
$pia_lang['WebServices_tablehead_TargetIP'] = 'Ziel IP';
$pia_lang['WebServices_tablehead_ScanTime'] = 'Aktualisierungszeit';
$pia_lang['WebServices_tablehead_Status_Code'] = 'HTTP Status Code';
$pia_lang['WebServices_tablehead_Response_Time'] = 'Antwortzeit';
$pia_lang['WebServices_Tab_Graph'] = 'Statistik';
$pia_lang['WebServices_label_URL'] = 'Service URL';
$pia_lang['WebServices_label_Tags'] = 'Tag';
$pia_lang['WebServices_label_MAC'] = 'Gerät';
$pia_lang['WebServices_label_MAC_Select'] = 'Auswahl';
$pia_lang['WebServices_label_Notes'] = 'Hinweis';
$pia_lang['WebServices_label_TargetIP'] = 'Ziel IP';
$pia_lang['WebServices_label_StatusCode'] = 'HTTP Status';
$pia_lang['WebServices_label_ScanTime'] = 'Aktualisierungszeit';
$pia_lang['WebServices_label_Response_Time'] = 'Antwortzeit';
$pia_lang['WebServices_label_AlertEvents'] = 'Alle Events';
$pia_lang['WebServices_label_AlertDown'] = 'Down';
$pia_lang['WebServices_label_Notification'] = 'Melde';
$pia_lang['WebServices_Chart_a'] = 'Service-Status über die letzten';
$pia_lang['WebServices_Chart_b'] = 'Stunden';
$pia_lang['WebServices_Page_down'] = 'Offline';
$pia_lang['WebServices_button_Delete_label'] = 'Service löschen';
$pia_lang['WebServices_button_Delete_Warning'] = 'Sind Sie sicher, dass Sie diesen Web Service löschen wollen?';
$pia_lang['WebServices_headline_NewService'] = 'Neuen Service hinzufügen';
$pia_lang['WebServices_Events_all'] = 'Alle Events';
$pia_lang['WebServices_Events_down'] = 'Down';
$pia_lang['WebServices_Events_none'] = 'nichts';
$pia_lang['WebServices_BoxTitle_General'] = 'Allgemein';
$pia_lang['WebServices_Stats_Code'] = 'Seiten Status';
$pia_lang['WebServices_Stats_Time'] = 'Antwortzeit';
$pia_lang['WebServices_Stats_Time_min'] = 'schnellste';
$pia_lang['WebServices_Stats_Time_max'] = 'langsamste';
$pia_lang['WebServices_Stats_Location'] = 'Standort';
$pia_lang['WebServices_Stats_IP'] = 'Aktuelle IP';
$pia_lang['WebServices_Stats_IPLocation'] = 'Länderzuordnung';
$pia_lang['WebServices_Stats_comment_a'] = '(Berechnet aus allen Scans von diesem Service)';

//////////////////////////////////////////////////////////////////
// WebServices Details Page - Backend
//////////////////////////////////////////////////////////////////

$pia_lang['BackWebServices_UpdServ'] = 'Der Web Service wurde aktualisiert';
$pia_lang['BackWebServices_UpdServError'] = 'Der Web Service wurde nicht aktualisiert';
$pia_lang['BackWebServices_InsServ'] = 'Der Web Service wurde gespeichert';
$pia_lang['BackWebServices_InsServError'] = 'Der Web Service wurde nicht gespeichert';
$pia_lang['BackWebServices_DelServ'] = 'Der Web Service wurde aus der Datenbank gelöscht';
$pia_lang['BackWebServices_DelServError'] = 'Der Web Service konnte nicht, oder nicht vollständig gelöscht werden';

//////////////////////////////////////////////////////////////////
// ICMP Monitoring Page
//////////////////////////////////////////////////////////////////

$pia_lang['ICMPMonitor_Title'] = 'ICMP Monitor';
$pia_lang['ICMPMonitor_headline_IP'] = 'Neue IP-Adresse überwachen';
$pia_lang['ICMPMonitor_label_IP'] = 'Host IP';
$pia_lang['ICMPMonitor_label_Hostname'] = 'Hostname';
$pia_lang['ICMPMonitor_label_RTT'] = 'avg. RTT';
$pia_lang['BackICMP_mon_disabled'] = 'ICMP Monitoring ist deaktiviert';
$pia_lang['BackICMP_mon_enabled'] = 'ICMP Monitoring ist aktiviert';
$pia_lang['BackICMP_mon_InsICMP'] = 'Der ICMP Host wurde gespeichert';
$pia_lang['BackICMP_mon_InsICMPError'] = 'Der ICMP Host wurde nicht gespeichert';
$pia_lang['BackICMP_mon_DelICMP'] = 'Der ICMP Host wurde aus der Datenbank gelöscht';
$pia_lang['BackICMP_mon_DelICMPError'] = 'Der ICMP Host konnte nicht, oder nicht vollständig gelöscht werden';
$pia_lang['BackICMP_mon_UpdICMP'] = 'Der ICMP Host wurde aktualisiert';
$pia_lang['BackICMP_mon_UpdICMPError'] = 'Der ICMP Host konnte nicht aktualisiert werden';
$pia_lang['ICMPMonitor_Shortcut_Online'] = 'Online';
$pia_lang['ICMPMonitor_Shortcut_Offline'] = 'Offline/Down';
$pia_lang['ICMPMonitor_Availability'] = 'Verfügbarkeit';

//////////////////////////////////////////////////////////////////
// Maintenance Page
//////////////////////////////////////////////////////////////////

$pia_lang['Maintenance_Title'] = 'Einstellungen und Wartung';
$pia_lang['Maintenance_database_path'] = 'Datenbank-Pfad';
$pia_lang['Maintenance_database_size'] = 'Datenbank-Größe';
$pia_lang['Maintenance_database_lastmod'] = 'Letzte Aktualisierung (DB)';
$pia_lang['Maintenance_database_backup'] = 'Sicherung: DB';
$pia_lang['Maintenance_config_backup'] = 'Sicherung: Config';
$pia_lang['Maintenance_database_backup_found'] = 'Sicherungen vorhanden';
$pia_lang['Maintenance_database_backup_total'] = 'Größe insgesamt';
$pia_lang['Maintenance_arp_status'] = 'Scan Status';
$pia_lang['Maintenance_arp_status_off'] = 'ist im Moment deaktiviert';
$pia_lang['Maintenance_arp_status_on'] = 'Scan(s) sind gerade aktiv';
$pia_lang['Maintenance_notification_config'] = 'Benachrichtigung (Geräte, ICMP)';
$pia_lang['Maintenance_notification_config_webmon'] = 'Benachrichtigung (Services)';
$pia_lang['Maintenance_Tools_Logviewer_Scan'] = 'Scan';
$pia_lang['Maintenance_Tools_Logviewer_Scan_empty'] = 'Es wird vermutlich gerade Scan ausgeführt';
$pia_lang['Maintenance_Tools_Logviewer_IPLog'] = 'Internet IP';
$pia_lang['Maintenance_Tools_Logviewer_IPLog_empty'] = 'Kein Log verfügbar';
$pia_lang['Maintenance_Tools_Logviewer_Vendor'] = 'Vendor Update';
$pia_lang['Maintenance_Tools_Logviewer_Vendor_empty'] = 'Kein Log verfügbar';
$pia_lang['Maintenance_Tools_Logviewer_Cleanup'] = 'Cleanup';
$pia_lang['Maintenance_Tools_Logviewer_Cleanup_empty'] = 'Kein Log verfügbar';
$pia_lang['Maintenance_Tools_Logviewer_Nmap'] = 'Nmap (Session)';
$pia_lang['Maintenance_Tools_Logviewer_Nmap_empty'] = 'Kein Log verfügbar';
$pia_lang['Maintenance_Tools_Logviewer_WebServices'] = 'Web Services';
$pia_lang['Maintenance_Tools_Logviewer_WebServices_empty'] = 'Kein Log verfügbar';
$pia_lang['Maintenance_Tools_Logviewer_WOL'] = 'Wake-on-LAN (Session)';
$pia_lang['Maintenance_Tools_Logviewer_WOL_empty'] = 'Kein Log verfügbar';
$pia_lang['Maintenance_themeselector_lable'] = 'Skin Auswahl';
$pia_lang['Maintenance_themeselector_empty'] = 'Skin wählen';
$pia_lang['Maintenance_themeselector_apply'] = 'Übernehmen';
$pia_lang['Maintenance_lang_selector_lable'] = 'Sprachauswahl';
$pia_lang['Maintenance_lang_selector_empty'] = 'Sprache wählen';
$pia_lang['Maintenance_lang_en_us'] = 'Englisch (US)';
$pia_lang['Maintenance_lang_de_de'] = 'Deutsch (DE)';
$pia_lang['Maintenance_lang_es_es'] = 'Spanisch (ES)';
$pia_lang['Maintenance_lang_fr_fr'] = 'Französisch (FR)';
$pia_lang['Maintenance_lang_it_it'] = 'Italienisch (IT)';
$pia_lang['Maintenance_lang_selector_apply'] = 'Übernehmen';
$pia_lang['Maintenance_Tools_Tab_Settings'] = 'Funktionen';
$pia_lang['Maintenance_Tools_Tab_Settings_Intro'] = 'Die hier aufgeführten Optionen bewirken serverseitige Konfigurationsänderungen. Diese Änderungen betreffen also alle Geräte die auf diese Seite zugreifen.';
$pia_lang['Maintenance_Tools_Tab_GUI'] = 'GUI';
$pia_lang['Maintenance_Tools_Tab_Tools'] = 'Wartung';
$pia_lang['Maintenance_Tools_Tab_BackupRestore'] = 'Datensicherung';
$pia_lang['Maintenance_Tools_Tab_Subheadline_a'] = 'Allgemein';
$pia_lang['Maintenance_Tools_Tab_Subheadline_b'] = 'Geräteübersicht konfigurieren';
$pia_lang['Maintenance_Tools_Tab_Subheadline_c'] = 'Sicherheit';
$pia_lang['Maintenance_Tools_Tab_Subheadline_d'] = 'Scans';
$pia_lang['Maintenance_Tools_Tab_Subheadline_e'] = 'FavIcon';
$pia_lang['Maintenance_Tools_Tab_Subheadline_e_Intro'] = 'Du kannst in dem Feld eine eigene URL zu deinem gewünschten FavIcon eintragen, oder zwischen lokalen oder remote (https://github.com/leiweibau/Pi.Alert) FavIcons wählen. Je Konfiguration kann es sein, dass lokale FavIcons nicht als HomeScreen Icon funktionieren.';
$pia_lang['Maintenance_Tool_darkmode'] = 'Dunkel Modus';
$pia_lang['Maintenance_Tool_darkmode_noti'] = 'Darstellungswechsel';
$pia_lang['Maintenance_Tool_darkmode_noti_text'] = 'Wechselt zwischen der hellen und der dunklen Darstellung. Wenn die Umschaltung nicht ordentlich funktionieren sollte, versuchen Sie den Browsercache zu löschen.';
$pia_lang['Maintenance_Tool_onlinehistorygraph'] = 'Aktivitätsverlauf';
$pia_lang['Maintenance_Tool_onlinehistorygraph_noti'] = 'Aktivitätsverlauf';
$pia_lang['Maintenance_Tool_onlinehistorygraph_noti_text'] = 'De-/Aktiviert den Aktivitätsverlauf auf der Geräte- und der Anwesenheitsseite.';
$pia_lang['Maintenance_Tool_webservicemon'] = 'Web Service Mon.';
$pia_lang['Maintenance_Tool_webservicemon_noti'] = 'Web Service Überwachung';
$pia_lang['Maintenance_Tool_webservicemon_noti_text'] = 'Aktiviert oder deaktiviert die Web Service Überwachung für Pi.Alert. Mit der Aktivierung, werden zusätzliche Elemente in der Oberfläche angezeigt. Mit der Deaktivierung, verschwinden diese wieder.';
$pia_lang['Maintenance_Tool_icmpmon'] = 'ICMP Monitoring';
$pia_lang['Maintenance_Tool_icmpmon_noti'] = 'ICMP Monitoring';
$pia_lang['Maintenance_Tool_icmpmon_noti_text'] = 'Aktiviert oder deaktiviert das ICMP Monitoring für Pi.Alert. Mit der Aktivierung, werden zusätzliche Elemente in der Oberfläche angezeigt. Mit der Deaktivierung, verschwinden diese wieder.';
$pia_lang['Maintenance_Tool_mainscan'] = 'Haupt Scan (arp)';
$pia_lang['Maintenance_Tool_mainscan_noti'] = 'Haupt Scan';
$pia_lang['Maintenance_Tool_mainscan_noti_text'] = 'Aktiviert oder deaktiviert die Haupt Scan Methode für Pi.Alert (Arp-scan). Die Sammlung von Daten über konfigurierte externe Quellen bleibt weiterhin aktiv.';
$pia_lang['Maintenance_Tool_DevListCol_noti'] = 'Geräteübersicht konfigurieren';
$pia_lang['Maintenance_Tool_DevListCol_noti_text'] = 'Möchten Sie die von Ihnen gemachten Änderungen speichern? Diese Änderung wirkt sich auf alle Geräte aus, mit denen Sie auf diese Seite zugreifen.';
$pia_lang['Maintenance_Tool_setapikey_false'] = 'Kein API-Key gesetzt';
$pia_lang['Maintenance_Tool_setapikey'] = 'Setze API-Key';
$pia_lang['Maintenance_Tool_setapikey_text'] = 'Mit dem API-Key ist es möglich, Ab&shy;fra&shy;gen an die Daten&shy;bank zu stellen, ohne die Web&shy;seite ver&shy;wenden zu müssen. Dies kann der Fall sein, wenn ein anderer Service oder Webseite auf die Daten dieser Daten&shy;bank zu&shy;grei&shy;fen soll. Existiert be&shy;reits ein API-Key, wird dieser ersetzt.';
$pia_lang['Maintenance_Tool_setapikey_noti'] = 'Setze API-Key';
$pia_lang['Maintenance_Tool_setapikey_noti_text'] = 'Möchtest du einen eventuell bestehenden API-Key durch einen neuen Key ersetzen? Bestehende Keys sind dann nicht mehr verwendbar.';
$pia_lang['Maintenance_Tool_ignorelist'] = 'Ignorierliste';
$pia_lang['Maintenance_Tool_ignorelist_false'] = 'Keine Ignorierliste konfiguriert';
$pia_lang['Maintenance_arpscantimer_empty'] = 'Timer setzen';
$pia_lang['Maintenance_Tool_arpscansw'] = 'Scans stoppen/starten';
$pia_lang['Maintenance_Tool_arpscansw_text'] = 'Schaltet alle Scans von Pi.Alert an oder aus. Wenn bei der Aktivierung des Timers kein Zeit&shy;raum festgelegt wur&shy;de, schal&shy;tet sich Pi.Alert nach einer Pause von 10min mit dem nächsten an&shy;ste&shy;henden Scan wieder ein. Bereits laufende Scans wer&shy;den dabei nicht beendet.';
$pia_lang['Maintenance_Tool_arpscansw_noti'] = 'arp-Scan stoppen/starten';
$pia_lang['Maintenance_Tool_arpscansw_noti_text'] = 'Wenn der Scan aus ist, bleibt er so lange aus bis er wieder aktiviert wird.';
$pia_lang['Maintenance_Tool_test_notification'] = 'Benachrichtigung testen';
$pia_lang['Maintenance_Tool_test_notification_text'] = 'Sendet eine Probe&shy;be&shy;nach&shy;rich&shy;tigung, um die korrekte Kon&shy;figu&shy;ra&shy;tion der Dienste zu testen.';
$pia_lang['Maintenance_Tool_test_notification_noti'] = 'Testbenachrichtigung';
$pia_lang['Maintenance_Tool_test_notification_noti_text'] = 'Soll eine Testbenachrichtigung über alle konfigurierten und aktivierten Benachrichtigungsdienste durchgeführt werden?';
$pia_lang['Maintenance_Tool_del_alldev'] = 'Alle Geräte löschen';
$pia_lang['Maintenance_Tool_del_alldev_text'] = 'Alle Ge&shy;räte wer&shy;den aus der Datenbank entfernt. Die Funktion betrifft keine Geräte, welche in der Netzwerk Übersicht erstellt wurden.';
$pia_lang['Maintenance_Tool_del_alldev_noti'] = 'Alle Geräte löschen';
$pia_lang['Maintenance_Tool_del_alldev_noti_text'] = 'Sind Sie sich sicher, dass Sie alle Geräte löschen wollen?';
$pia_lang['Maintenance_Tool_del_unknowndev'] = 'Löschen der (unknown) Geräte';
$pia_lang['Maintenance_Tool_del_unknowndev_text'] = 'Alle Geräte mit dem Namen (unknown) wer&shy;den aus der Daten&shy;bank ge&shy;löscht.';
$pia_lang['Maintenance_Tool_del_unknowndev_noti'] = 'Lösche (unknown) Geräte';
$pia_lang['Maintenance_Tool_del_unknowndev_noti_text'] = 'Sind Sie sicher, dass Sie alle (unknown) Geräte aus der Datenbank löschen wollen?';
$pia_lang['Maintenance_Tool_del_allevents'] = 'Alle Ereignisse löschen';
$pia_lang['Maintenance_Tool_del_allevents_text'] = 'Alle Er&shy;eignisse werden aus der Daten&shy;bank ge&shy;löscht. Dies setzt auch die An&shy;wesen&shy;heit zu&shy;rück. Es kann ab dem Moment zu un&shy;gül&shy;tigen Sitzungen kom&shy;men. Ein Scan, wäh&shy;rend das be&shy;treffen&shy;de Gerät "online" ist, sollte das Problem lösen.';
$pia_lang['Maintenance_Tool_del_allevents_noti'] = 'Alle Ereignisse löschen';
$pia_lang['Maintenance_Tool_del_allevents_noti_text'] = 'Sind Sie sicher, dass Sie alle Ereignisse aus der Datenbank löschen wollen. Dies setzt die Anwesenheit aller Geräte zurück.';
$pia_lang['Maintenance_Tool_del_Inactive_Hosts'] = 'Lösche inaktive Geräte';
$pia_lang['Maintenance_Tool_del_Inactive_Hosts_text'] = 'Es werden alle Geräte gelöscht, die seit 30 Tagen inaktiv sind. Die Events dieser Geräte werden ebenfalls aus der Datenbank ent&shy;fernt.';
$pia_lang['Maintenance_Tool_backup'] = 'DB Sicherung';
$pia_lang['Maintenance_Tool_backup_text'] = 'Die Datenbank-Sicher&shy;ungen befinden sich im Datenbank-Ver&shy;zeich&shy;nis, gepackt als zip-Archive, benannt mit dem Er&shy;stell&shy;ungs&shy;datum. Es gibt keine maximale Anzahl von Backups.';
$pia_lang['Maintenance_Tool_backup_noti'] = 'DB Sicherung';
$pia_lang['Maintenance_Tool_backup_noti_text'] = 'Sind Sie sicher, dass Sie die Datenbank jetzt sichern möchten. Prüfen Sie, dass gerade keine Scans stattfinden.';
$pia_lang['Maintenance_Tool_backupcsv'] = 'Geräte/Services in<br>CSV Datei sichern';
$pia_lang['Maintenance_Tool_backupcsv_text'] = 'Geräte, Web Servives und Geräte aus dem ICMP Monitoring werden in CSV-Dateien exportiert und als zip-Archive gespeichert. Dies dient als Notfalllösung, falls wegen einer defekten Datenbank, alles wieder eingegeben werden muss. Ein Import ist im Moment noch nicht möglich.';
$pia_lang['Maintenance_Tool_backupcsv_noti'] = 'Geräte/Services in CSV Datei sichern';
$pia_lang['Maintenance_Tool_backupcsv_noti_text'] = 'Sind Sie sicher, dass Sie jetzt die Geräte und Web Services Listen als CSV-Dateien exportieren möchten?.';
$pia_lang['Maintenance_Tool_restore'] = 'DB Wiederherstellung';
$pia_lang['Maintenance_Tool_restore_blocked'] = 'nicht verfügbar';
$pia_lang['Maintenance_Tool_restore_text'] = 'Das neuste Backup kann über diese Funk&shy;tion wie&shy;derhergestellt wer&shy;den. Ältere Sicher&shy;ungen müssen manuell wie&shy;der&shy;hergestellt wer&shy;den. Es empfiehlt sich eine Integritäts&shy;prüfung nach der Wieder&shy;her&shy;stellung zu machen, falls die Datenbank bei der Sicherung geöffnet war.';
$pia_lang['Maintenance_Tool_restore_noti'] = 'DB Wiederherstellung';
$pia_lang['Maintenance_Tool_restore_noti_text'] = 'Sind Sie sicher, dass Sie die Datenbank aus der neusten Sicherung wiederherstellen möchten? Prüfen Sie, dass gerade keine Scans stattfinden.';
$pia_lang['Maintenance_Tool_latestdb_download'] = 'Neuste DB Sicherung downloaden';
$pia_lang['Maintenance_Tool_latestconf_download'] = 'Aktuelle pialert.conf downloaden';
$pia_lang['Maintenance_Tool_CSVExport_download'] = 'CSV Export downloaden';
$pia_lang['Maintenance_Tool_purgebackup'] = 'Sicherungen aufräumen';
$pia_lang['Maintenance_Tool_purgebackup_text'] = 'Es werden, bis auf die letzten 3 Backups, alle übrigen Backups ge&shy;löscht. Dies betrifft die Sicherungen der Daten&shy;bank und die der Kon&shy;fi&shy;gurationsdatei';
$pia_lang['Maintenance_Tool_purgebackup_noti'] = 'Sicherungen aufräumen';
$pia_lang['Maintenance_Tool_purgebackup_noti_text'] = 'Sind Sie sicher, alle Backups, bis auf die letzten 3 löschen möchten?';
$pia_lang['Maintenance_Tool_del_ActHistory'] = 'Löschen der Netzwerkaktivität';
$pia_lang['Maintenance_Tool_del_ActHistory_text'] = 'Der Graph für die Netz&shy;werkaktivität wird zu&shy;rück&shy;gesetzt. Die Events wer&shy;den hiervon nicht beeinflusst.';
$pia_lang['Maintenance_Tool_del_ActHistory_noti'] = 'Netzwerkaktivität löschen';
$pia_lang['Maintenance_Tool_del_ActHistory_noti_text'] = 'Sind Sie sicher, dass Sie die Netzwerkaktivität zurücksetzen möchten?';
$pia_lang['Maintenance_Tool_loginenable'] = 'Login aktivieren';
$pia_lang['Maintenance_Tool_loginenable_text'] = 'Nach der Aktivierung gelangst du automatisch auf die Anmeldeseite. Wenn du zuvor noch kein Passwort gesetzt hast, ist "123456" das Standardpasswort.';
$pia_lang['Maintenance_Tool_loginenable_noti'] = 'Login aktivieren';
$pia_lang['Maintenance_Tool_loginenable_noti_text'] = 'Bist du dir sicher, dass du den Login aktivieren möchtest?';
$pia_lang['Maintenance_Tool_logindisable'] = 'Login deaktivieren';
$pia_lang['Maintenance_Tool_logindisable_text'] = 'Der Login wird de&shy;akti&shy;viert. Jeder Nutzer hat nun wieder die Mög&shy;lich&shy;keit auf die Pi.Alert-Seite zuzugreifen.';
$pia_lang['Maintenance_Tool_logindisable_noti'] = 'Login deaktivieren';
$pia_lang['Maintenance_Tool_logindisable_noti_text'] = 'Bist du dir sicher, dass du den Login deaktivieren möchtest?';
$pia_lang['Maintenance_ConfEditor_Start'] = 'Pi.Alert Config bearbeiten';
$pia_lang['Maintenance_ConfEditor_Hint'] = 'Hinweise zum Editor';
$pia_lang['Maintenance_ConfEditor_Backup'] = 'Backup anlegen';
$pia_lang['Maintenance_ConfEditor_Restore'] = 'Vorherige Version';
$pia_lang['Maintenance_ConfEditor_Restore_noti'] = 'Vorherige Version';
$pia_lang['Maintenance_ConfEditor_Restore_noti_text'] = 'Es wird die letzte Version der Konfigurationsdatei zurückgespielt. Die "vorherige Version" ist entweder, die des letzten Backups, oder die Version vor der letzten Speicherung. Je nachdem welche aktueller ist.';
$pia_lang['Maintenance_ConfEditor_Backup_info'] = 'Neben der Datei "pialert-prev.bak" wird eine weitere Sich&shy;erung mit dem aktuellen Da&shy;tum inkl. Uhrzeit an&shy;ge&shy;legt. Diese Sicher&shy;ung muss im Bedarfsfall manuell wieder&shy;her&shy;gestellt werden (umbenennen in "pialert.conf"). Eine vorhandene "pialert-prev.bak"-Datei wird im&shy;mer wieder überschrieben.';
$pia_lang['Maintenance_ConfEditor_Restore_info'] = 'Diese Funktion stellt die Kon&shy;fi&shy;gura&shy;tionsdatei aus der Datei "pialert-prev.bak" wieder her. Die Datei "pialert-prev.bak" wird beim Speichern und bei der Erstellung einer Sicherung er&shy;zeugt.';
$pia_lang['Maintenance_ConfEditor_Save_info'] = 'Der Inhalt des Textfeldes mit eventuellen Änderungen wird in die Datei "pialert.conf" ge&shy;spei&shy;chert. Die vorherige Kon&shy;figu&shy;ration wird als "pialert-prev.bak" gesichert. Mit jeder Speicherung wird die Datei "pialert-prev.bak" wieder mit der vorherigen Version der Kon&shy;figu&shy;rationsdatei überschrieben.';
$pia_lang['Maintenance_Tool_ConfBackup'] = 'Config-Backup anlegen';
$pia_lang['Maintenance_Tool_ConfBackup_text'] = 'Neben der Datei "pialert-prev.bak" wird eine weitere Sicherung mit dem aktuellen Da&shy;tum inkl. Uhrzeit an&shy;ge&shy;legt. Diese Sicherung muss im Bedarfsfall ma&shy;nuell wieder&shy;hergestellt werden (umbenennen in "pialert.conf").';
$pia_lang['FavIcon_color_white'] = 'weis';
$pia_lang['FavIcon_color_black'] = 'schwarz';
$pia_lang['FavIcon_color_red'] = 'rot';
$pia_lang['FavIcon_color_blue'] = 'blau';
$pia_lang['FavIcon_color_green'] = 'grün';
$pia_lang['FavIcon_color_yellow'] = 'gelb';
$pia_lang['FavIcon_color_purple'] = 'lila';
$pia_lang['FavIcon_logo_white'] = 'helles Logo';
$pia_lang['FavIcon_logo_black'] = 'dunkles Logo';
$pia_lang['FavIcon_mode_glass'] = 'glanz';
$pia_lang['FavIcon_mode_flat'] = 'matt';
$pia_lang['FavIcon_local'] = 'lokal';
$pia_lang['FavIcon_remote'] = 'remote';

//////////////////////////////////////////////////////////////////
// Maintenance Page (Backend)
//////////////////////////////////////////////////////////////////

$pia_lang['BackDevices_Arpscan_disabled'] = 'Automatischer Arp-Scan deaktiviert.';
$pia_lang['BackDevices_Arpscan_enabled'] = 'Automatischer Arp-Scan aktiviert';
$pia_lang['BackDevices_setapikey'] = 'API-Key wurde gesetzt';
$pia_lang['BackDevices_test_notification'] = 'Testnachricht wurde gesendet';
$pia_lang['BackDevices_darkmode_disabled'] = 'Heller Modus aktiviert';
$pia_lang['BackDevices_darkmode_enabled'] = 'Dunkler Modus aktiviert';
$pia_lang['BackDevices_webservicemon_disabled'] = 'Web Service Überwachung ist deaktiviert';
$pia_lang['BackDevices_webservicemon_enabled'] = 'Web Service Überwachung ist aktiviert';
$pia_lang['BackDevices_MainScan_disabled'] = 'Haupt Scan ist deaktiviert';
$pia_lang['BackDevices_MainScan_enabled'] = 'Haupt Scan ist aktiviert';
$pia_lang['BackDevices_onlinehistorygraph_disabled'] = 'Aktivitätsverlauf deaktiviert';
$pia_lang['BackDevices_onlinehistorygraph_enabled'] = 'Aktivitätsverlauf aktiviert';
$pia_lang['BackDevices_Restore_CopError'] = 'Die originale Datenbank konnte nicht kopiert werden';
$pia_lang['BackDevices_Restore_okay'] = 'Die Wiederherstellung wurde erfolgreich ausgeführt';
$pia_lang['BackDevices_Restore_Failed'] = 'Die Wiederherstellung ist fehlgeschlagen. Stellen Sie das Backup manuell her';
$pia_lang['BackDevices_Backup_WALError'] = 'Die originale Datenbank wurde nicht kopiert, da möglicherweise Transaktionen offen sind.';
$pia_lang['BackDevices_Backup_IntegrityError'] = 'Die kopierte Datenbank hat die Integritätsprüfung nicht bestanden.';
$pia_lang['BackDevices_Backup_CopError'] = 'Die originale Datenbank konnte nicht gesichert werden';
$pia_lang['BackDevices_Backup_okay'] = 'Das Backup wurde erfolgreich beendet';
$pia_lang['BackDevices_Backup_Failed'] = 'Das Backup wurde teilweise ausgeführt. Das Archiv ist entweder leer oder nicht vorhanden';
$pia_lang['BackDevices_BackupCSV_FailedExport'] = 'Eine oder mehrere CSV-Dateien konnten nicht erstellt werden.';
$pia_lang['BackDevices_BackupCSV_FailedZip'] = 'Das Archiv mit den CSV-Dateien konnten nicht erstellt werden.';
$pia_lang['BackDevices_BackupCSV_okay'] = 'Das Archiv mit den CSV-Dateien wurde erfolgreich erstellt.';
$pia_lang['BackDevices_DBTools_DelDev_a'] = 'Gerät erfolgreich gelöscht';
$pia_lang['BackDevices_DBTools_DelDev_b'] = 'Geräte erfolgreich gelöscht';
$pia_lang['BackDevices_DBTools_DelEvents'] = 'Events erfolgreich gelöscht';
$pia_lang['BackDevices_DBTools_DelEventsError'] = 'Fehler beim Löschen der Ereignisse.';
$pia_lang['BackDevices_DBTools_DelDevError_a'] = 'Fehler beim Löschen des Gerätes.';
$pia_lang['BackDevices_DBTools_DelDevError_b'] = 'Fehler beim Löschen der Geräte.';
$pia_lang['BackDevices_DBTools_UpdDev'] = 'Gerät erfolgreich aktualisiert.';
$pia_lang['BackDevices_DBTools_UpdDevError'] = 'Fehler beim Aktualisieren des Gerätes.';
$pia_lang['BackDevices_DBTools_Purge'] = 'Die ältesten Backups wurden gelöscht.';
$pia_lang['BackDevices_DBTools_DelActHistory'] = 'Die Anzeige der Netzwerkaktivität wurde zurückgesetzt.';
$pia_lang['BackDevices_DBTools_DelActHistoryError'] = 'Fehler beim Zurücksetzen der Netzwerkaktivitätsanzeige.';
$pia_lang['BackDevices_DBTools_DelInactHosts'] = 'Inaktive Hosts wurden gelöscht.';
$pia_lang['BackDevices_DBTools_DelInactHostsError'] = 'Es trat, bei dem Versuch inaktive Hosts zu löschen, ein Fehler auf.';
$pia_lang['BackDevices_Login_disabled'] = 'Login deaktiviert.';
$pia_lang['BackDevices_Login_enabled'] = 'Login aktiviert.';
$pia_lang['BackDevices_Theme_set'] = 'Theme wird angewendet.';
$pia_lang['BackDevices_Theme_notset'] = 'Theme wird nicht angewendet.';
$pia_lang['BackDevices_Theme_invalid'] = 'Es wurde kein Theme ausgewählt.';
$pia_lang['BackDevices_Language_set'] = 'Sprache wird angewendet.';
$pia_lang['BackDevices_Language_notset'] = 'Sprache wird nicht angewendet.';
$pia_lang['BackDevices_Language_invalid'] = 'Es wurde kein Sprache ausgewählt.';
$pia_lang['BackDevices_DevListCol_noti_text'] = 'Tabelleneinstellung wird gespeichert.';
$pia_lang['BackDevices_ConfEditor_CopError'] = 'Die Sicherung der Konfiguration ist nicht möglich.';
$pia_lang['BackDevices_ConfEditor_CopOkay'] = 'Die Sicherung der Konfiguration ist abgeschlossen.';
$pia_lang['BackDevices_ConfEditor_RestoreError'] = 'Die letzte Version der Konfiguration konnte nicht wieder hergestellt werden.';
$pia_lang['BackDevices_ConfEditor_RestoreOkay'] = 'Die letzte Version der Konfiguration wurde wieder hergestellt.';
$pia_lang['BackDevices_Report_Delete'] = ' Benachrichtigung(en) wurde(n) gelöscht.';
$pia_lang['BackFiles_FavIcon_invalidURL'] = 'Eine ungültige URL wurde eingegeben';
$pia_lang['BackFiles_FavIcon_ErrorURL'] = 'Ein manuell eingegebens FavIcon muss eine URL sein. Pfadangaben für eine lokale Datei werden nicht gespeichert';
$pia_lang['BackFiles_FavIcon_okay'] = 'Das neue FavIcon wurde gespeichert';

//////////////////////////////////////////////////////////////////
// Network Page
//////////////////////////////////////////////////////////////////

$pia_lang['Network_Title'] = 'Netzwerkübersicht';
$pia_lang['Network_ManageDevices'] = 'Netzwerkelemente verwalten';
$pia_lang['Network_ManageAdd_Name'] = 'Name des neuen Gerätes';
$pia_lang['Network_ManageAdd_Name_text'] = 'Name ohne Sonderzeichen';
$pia_lang['Network_ManageAdd_Type'] = 'Gerätetyp';
$pia_lang['Network_ManageAdd_Type_text'] = '-- Typ wählen --';
$pia_lang['Network_ManageAdd_Port'] = 'Portanzahl';
$pia_lang['Network_ManageAdd_Port_text'] = 'bei WLAN oder Powerline leer lassen';
$pia_lang['Network_ManageAdd_Submit'] = 'Gerät hinzufügen';
$pia_lang['Network_ManageEdit_ID'] = 'Gerät zum Bearbeiten auswählen';
$pia_lang['Network_ManageEdit_ID_text'] = '-- Gerät wählen --';
$pia_lang['Network_ManageEdit_Name'] = 'Neuer Name';
$pia_lang['Network_ManageEdit_Name_text'] = 'Leer lassen wenn keine Änderung erfolgt.';
$pia_lang['Network_ManageEdit_Type'] = 'Neuer Typ';
$pia_lang['Network_ManageEdit_Type_text'] = '-- Typ wählen --';
$pia_lang['Network_ManageEdit_Port'] = 'Neue Portanzahl';
$pia_lang['Network_ManageEdit_Port_text'] = 'Bei WLAN oder Powerline leer lassen';
$pia_lang['Network_ManageEdit_Downlink'] = 'manuelle Port-Konfiguration (Ziel-MAC,lokaler Port)';
$pia_lang['Network_ManageEdit_Downlink_text'] = '0a:1b:3c:4d:5e:6f,16;Ziel-MAC 2,Port 2;';
$pia_lang['Network_ManageEdit_Submit'] = 'Bearbeitung speichern';
$pia_lang['Network_ManageDel_Name'] = 'Gerät zum Löschen auswählen';
$pia_lang['Network_ManageDel_Name_text'] = '-- Gerät wählen --';
$pia_lang['Network_ManageDel_Submit'] = 'Gerät löschen';
$pia_lang['Network_Table_State'] = 'Status';
$pia_lang['Network_Table_Hostname'] = 'Gerätename';
$pia_lang['Network_Table_IP'] = 'Host IP';
$pia_lang['Network_UnassignedDevices'] = 'Nicht zugewiesene Geräte';
$pia_lang['NetworkSettings_Title'] = 'Netzwerk (Einstellungen)';
$pia_lang['Network_ManageDevices_Intro'] = 'Dieser Bereich dient dem Erstellen von transparenten/IP-losen (Unmanaged) Geräten, wie Hubs oder Switches, sowie aktiven Geräten wie Router, managed Switches oder AccessPoint,
											welche die Netzwerkstruktur beeinflussen. Auch bereits durch Pi.Alert erkannte Geräte, müssen hier für die Darstellung neu erstellt werden. Die Bearbeitung, oder das Löschen,
											bereits durch Pi.Alert erkannter Geräte, ist unabhängig von der "<span class="text-maroon help_faq_code">' . $pia_lang['Navigation_Devices'] . '</span>"-Liste und hat nur
											Bedeutung für die "<span class="text-maroon help_faq_code">' . $pia_lang['Navigation_Network'] . '</span>" Seite.';
$pia_lang['Network_Unmanaged_Devices'] = 'Nicht scanbare Geräte verwalten';
$pia_lang['Network_Unmanaged_Devices_Intro'] = 'An dieser Stelle können Endgeräte, welche zwar Ports oder Verbindungen an z.B Switches oder Routern belegen, selbst jedoch keine Netzwerkfunktionalität haben, erstellt werden.
											Auch Geräte die nicht erkannt werden können, aber der Übersicht wegen dargestellt werden sollen, können hier berücksichtigt werden. Die hier erstellten Geräte tauchen ausschließlich
											auf der "<span class="text-maroon help_faq_code">' . $pia_lang['Navigation_Network'] . '</span>" Seite auf.';
$pia_lang['Network_Unmanaged_Devices_Connected'] = 'Verbunden mit';
$pia_lang['Network_Unmanaged_Devices_Connected_text'] = 'Gerät auswählen';
$pia_lang['Network_Unmanaged_Devices_Port'] = 'Am Port';
$pia_lang['Network_Unmanaged_Devices_Port_text'] = 'Am Portnummer am ausgewählten Gerät';

//////////////////////////////////////////////////////////////////
// Reports Page
//////////////////////////////////////////////////////////////////

$pia_lang['Reports_Title'] = 'Benachrichtigungen';
$pia_lang['Reports_delete_all'] = 'Alle Benachrichtigungen löschen';
$pia_lang['Reports_delete_all_noti'] = 'Alle Benachrichtigungen löschen';
$pia_lang['Reports_delete_all_noti_text'] = 'Es werden alle Benachrichtigungen gelöscht. Der Zähler wird damit zurückgesetzt.';
$pia_lang['Reports_Rogue_hint'] = 'Eine erneute Meldung über einen unbekannten DHCP Server erfolgt erst nach dem Löschen dieser Meldung.';

//////////////////////////////////////////////////////////////////
// UpdateCheck
//////////////////////////////////////////////////////////////////

$pia_lang['Maintenance_Tools_Updatecheck'] = 'Prüfe auf Updates';
$pia_lang['Maintenance_Github_package_a'] = 'Neueste Version: ';
$pia_lang['Maintenance_Github_package_b'] = 'Uhr';
$pia_lang['Updatecheck_Title'] = 'Update Check';
$pia_lang['Updatecheck_cur'] = 'Derzeit genutzte Pi.Alert Version';
$pia_lang['Updatecheck_new'] = 'Neueste Pi.Alert Version auf Github';
$pia_lang['GeoLiteDB_Title'] = 'GeoLite2 DB Prüfung';
$pia_lang['GeoLiteDB_cur'] = 'GeoLite2 DB geladen am';
$pia_lang['GeoLiteDB_new'] = 'Neueste GeoLite2 DB auf Github';
$pia_lang['Updatecheck_RN'] = 'Pi.Alert Update Hinweise';
$pia_lang['Updatecheck_RN2'] = 'Pi.Alert Update Prüfung';
$pia_lang['Updatecheck_U2D'] = 'Du nutzt bereits die aktuellest Version';
$pia_lang['GeoLiteDB_button_del'] = 'GeoLite2-Datenbank löschen';
$pia_lang['GeoLiteDB_button_ins'] = 'GeoLite2-Datenbank installieren';
$pia_lang['GeoLiteDB_button_upd'] = 'GeoLite2-Datenbank aktualisieren';
$pia_lang['GeoLiteDB_credits'] = 'Die Datenbank wird von <a href="https://github.com/P3TERX/GeoLite.mmdb" target="_blank">github.com/P3TERX/GeoLite.mmdb</a> heruntergeladen. Die GeoLite2 Datenbank ist ein Produkt von <a href="https://dev.maxmind.com/geoip/geolite2-free-geolocation-data" target="_blank">MaxMind</a>';
$pia_lang['GeoLiteDB_Installnotes'] = 'Du kannst die Datenbank über den Reiter ' . $pia_lang['WebServices_Tab_Graph'] . ' auf der Detailansicht eines beliebigen Web Service installieren.';
$pia_lang['GeoLiteDB_absent'] = 'DB nicht installiert';

//////////////////////////////////////////////////////////////////
// System Info Page
//////////////////////////////////////////////////////////////////

$pia_lang['SysInfo_storage_note'] = 'Es ist möglich, dass die Speicherbelegung nicht für alle oben gelisteten Laufwerke ermittelt werden kann. Dies ist abhängig davon, unter welchem Benutzer die Laufwerke gemoutet sind.';

//////////////////////////////////////////////////////////////////
// Speedtest
//////////////////////////////////////////////////////////////////

$pia_lang['ookla_postinstall_note'] = 'Bevor Sie den Speedtest-Client von Ookla nutzen können, müssen Sie einmalig den Befehl "sudo ./speedtest" im Verzeichnis "$HOME/pialert/back/speedtest/" ausführen. Die Speedtest-Schaltfläche wird mit einem Neuladen der Seite aktiviert, funktioniert aber erst, nachdem die Ookla-Lizenz akzeptiert wurde.';
$pia_lang['ookla_devdetails_tab_title'] = 'Speedtest Verlauf';
$pia_lang['ookla_devdetails_required'] = 'Der Verlauf der Speedtest Messergebisse wird zur Zeit nur mit dem offiziellen Speedtest von Ookla (<a href="https://www.speedtest.net/apps/cli" target="blank">speedtest.net</a>) unterstützt.';
$pia_lang['ookla_devdetails_tab_headline'] = 'Speedtest Verlauf';
$pia_lang['ookla_devdetails_table_time'] = 'Datum';
$pia_lang['ookla_devdetails_table_isp'] = 'ISP';
$pia_lang['ookla_devdetails_table_server'] = 'Server';
$pia_lang['ookla_devdetails_table_ping'] = 'Ping';
$pia_lang['ookla_devdetails_table_down'] = 'Download';
$pia_lang['ookla_devdetails_table_up'] = 'Upload';

// =============================================================================================================

$pia_journ_lang['Journal_TableHead_Class'] = 'Methode';
$pia_journ_lang['Journal_TableHead_Trigger'] = 'Auslöser';

$pia_journ_lang['Title'] = 'Anwendungsjournal';
$pia_journ_lang['File_hash'] = 'pialert.conf - Hash';
// Frontend
$pia_journ_lang['a_000'] = 'Konfigurationsdatei';
$pia_journ_lang['a_001'] = 'GUI Zugriff';
$pia_journ_lang['a_002'] = 'Pi.Alert Scans';
$pia_journ_lang['a_005'] = 'GUI Config';
$pia_journ_lang['a_010'] = 'DB Wartung';
$pia_journ_lang['a_020'] = 'Geräte';
$pia_journ_lang['a_021'] = 'Multi-Editor';
$pia_journ_lang['a_025'] = 'Tools';
$pia_journ_lang['a_030'] = 'Web Service Monitoring';
$pia_journ_lang['a_031'] = 'ICMP Monitoring';
$pia_journ_lang['a_032'] = 'Haupt Scan';
$pia_journ_lang['a_040'] = 'Netzwerk Übersicht';
$pia_journ_lang['a_050'] = 'Reports';
$pia_journ_lang['a_060'] = 'Update Check';
$pia_journ_lang['a_070'] = 'API';
// pialert-cli
$pia_journ_lang['b_002'] = $pia_journ_lang['a_002'];
$pia_journ_lang['b_010'] = 'DB Wartung';
$pia_journ_lang['b_030'] = $pia_journ_lang['a_030'];
$pia_journ_lang['b_031'] = $pia_journ_lang['a_031'];
$pia_journ_lang['b_032'] = $pia_journ_lang['a_032'];
// cronjob
$pia_journ_lang['c_002'] = $pia_journ_lang['a_002'];
$pia_journ_lang['c_010'] = $pia_journ_lang['a_010'];
//LogStrings
$pia_journ_lang['LogStr_0001'] = 'Eintrag hinzugefügt';
$pia_journ_lang['LogStr_0002'] = 'Eintrag bearbeitet';
$pia_journ_lang['LogStr_0003'] = 'Eintrag gelöscht';
$pia_journ_lang['LogStr_0004'] = 'Eintrag bearbeitet (mit Fehler)';
$pia_journ_lang['LogStr_0005'] = 'Eintrag gelöscht (mit Fehler)';
$pia_journ_lang['LogStr_0006'] = 'Letzte Änderung der Konfigurationsdatei zurückgesetzt';
$pia_journ_lang['LogStr_0007'] = 'Sicherung der Konfiguration erstellt';
$pia_journ_lang['LogStr_0008'] = 'GeoLite2-Datenbank installiert';
$pia_journ_lang['LogStr_0009'] = 'GeoLite2-Datenbank gelöscht';
$pia_journ_lang['LogStr_0010'] = 'Datenbank aktualisiert';
$pia_journ_lang['LogStr_0011'] = 'Datenbank-Sicherung erstellt';
$pia_journ_lang['LogStr_0012'] = 'Datenbank-Sicherung wiederhergestellt';
$pia_journ_lang['LogStr_0013'] = 'Sicherungen aufgeräumt (Konfigurationsdatei und Datenbank)';
$pia_journ_lang['LogStr_0014'] = 'Inaktive Hosts löschen (mit Fehler)';
$pia_journ_lang['LogStr_0015'] = 'Inaktive Hosts löschen';
$pia_journ_lang['LogStr_0016'] = 'Alle Hosts ohne MAC-Addresse löschen';
$pia_journ_lang['LogStr_0017'] = 'Alle Hosts ohne MAC-Addresse löschen (mit Fehler)';
$pia_journ_lang['LogStr_0018'] = 'Alle (unknown)-Hosts löschen';
$pia_journ_lang['LogStr_0019'] = 'Alle (unknown)-Hosts löschen (mit Fehler)';
$pia_journ_lang['LogStr_0020'] = 'Alle Event eines Gerätes löschen';
$pia_journ_lang['LogStr_0021'] = 'Alle Event eines Gerätes löschen (mit Fehler)';
$pia_journ_lang['LogStr_0022'] = 'Alle Hosts aus der Geräte-Liste löschen';
$pia_journ_lang['LogStr_0023'] = 'Alle Hosts aus der Geräte-Liste löschen (mit Fehler)';
$pia_journ_lang['LogStr_0024'] = 'Alle Events löschen';
$pia_journ_lang['LogStr_0025'] = 'Alle Events löschen (mit Fehler)';
$pia_journ_lang['LogStr_0026'] = 'Netzwerkaktivität zurücksetzen';
$pia_journ_lang['LogStr_0027'] = 'Netzwerkaktivität zurücksetzen (mit Fehler)';
$pia_journ_lang['LogStr_0030'] = 'Aktive Netzwerkkomponente hinzugefügt (Switch, Router, etc)';
$pia_journ_lang['LogStr_0031'] = 'Aktive Netzwerkkomponente bearbeitet (Switch, Router, etc)';
$pia_journ_lang['LogStr_0032'] = 'Aktive Netzwerkkomponente gelöscht (Switch, Router, etc)';
$pia_journ_lang['LogStr_0033'] = 'Nicht scanbares Gerät hinzugefügt (Hubs, PoE Geräte, Docker, etc.)';
$pia_journ_lang['LogStr_0034'] = 'Nicht scanbares Gerät bearbeitet (Hubs, PoE Geräte, Docker, etc.)';
$pia_journ_lang['LogStr_0035'] = 'Nicht scanbares Gerät gelöscht (Hubs, PoE Geräte, Docker, etc.)';
$pia_journ_lang['LogStr_0036'] = 'Geräte, Web Services und ICMP Hosts im CSV-Format exportiert.';
$pia_journ_lang['LogStr_0050'] = 'Passwortschutz von Pi.Alert aktiviert';
$pia_journ_lang['LogStr_0051'] = 'Passwortschutz von Pi.Alert deaktiviert';
$pia_journ_lang['LogStr_0052'] = 'Spaltenkonfiguration der Geräte-Liste geändert';
$pia_journ_lang['LogStr_0053'] = 'Theme geändert';
$pia_journ_lang['LogStr_0054'] = 'Sprache geändert';
$pia_journ_lang['LogStr_0055'] = $pia_lang['BackDevices_darkmode_disabled'];
$pia_journ_lang['LogStr_0056'] = $pia_lang['BackDevices_darkmode_enabled'];
$pia_journ_lang['LogStr_0057'] = $pia_lang['BackDevices_onlinehistorygraph_disabled'];
$pia_journ_lang['LogStr_0058'] = $pia_lang['BackDevices_onlinehistorygraph_enabled'];
$pia_journ_lang['LogStr_0059'] = 'FavIcon geändert';
$pia_journ_lang['LogStr_0061'] = 'Pi.Alert Update verfügbar';
$pia_journ_lang['LogStr_0062'] = 'Kein Pi.Alert Update verfügbar';
$pia_journ_lang['LogStr_0063'] = 'GeoLite2 DB Update verfügbar';
$pia_journ_lang['LogStr_0064'] = 'Kein GeoLite2 DB Update verfügbar';
$pia_journ_lang['LogStr_0065'] = 'GeoLite2 DB nicht installiert';
$pia_journ_lang['LogStr_0101'] = 'Datenbank aufgeräumt und optimiert';
$pia_journ_lang['LogStr_0210'] = 'Individuellen nmap Scan durchgeführt';
$pia_journ_lang['LogStr_0251'] = 'Wake-on-lan ausgeführt';
$pia_journ_lang['LogStr_0255'] = 'Online Speedtest ausgeführt';
$pia_journ_lang['LogStr_0301'] = $pia_lang['BackDevices_webservicemon_enabled'];
$pia_journ_lang['LogStr_0302'] = $pia_lang['BackDevices_webservicemon_disabled'];
$pia_journ_lang['LogStr_0303'] = $pia_lang['BackICMP_mon_enabled'];
$pia_journ_lang['LogStr_0304'] = $pia_lang['BackICMP_mon_disabled'];
$pia_journ_lang['LogStr_0500'] = 'Testbenachrichtigung(en) gesendet';
$pia_journ_lang['LogStr_0503'] = 'Report gelöscht';
$pia_journ_lang['LogStr_0504'] = 'Alle Reports gelöscht';
$pia_journ_lang['LogStr_0510'] = 'Pi.Alert wieder aktiviert';
$pia_journ_lang['LogStr_0511'] = 'Pi.Alert deaktiviert (mit Zeitangabe)';
$pia_journ_lang['LogStr_0512'] = 'Pi.Alert deaktiviert (für 10 min)';
$pia_journ_lang['LogStr_0513'] = 'Pi.Alert automatisch reaktiviert';
$pia_journ_lang['LogStr_0700'] = 'API-Key gesetzt';
$pia_journ_lang['LogStr_9001'] = 'Zugriff auf die Web-Oberfläche gestartet';
$pia_journ_lang['LogStr_9002'] = 'Logout durchgeführt';
$pia_journ_lang['LogStr_9003'] = 'Fehler bei der Anmeldung (Passwort falsch!)';
$pia_journ_lang['LogStr_9004'] = 'Zugriff auf die Web-Oberfläche gestartet (mit Cookie)';
$pia_journ_lang['LogStr_9991'] = $pia_lang['BackDevices_MainScan_enabled'];
$pia_journ_lang['LogStr_9992'] = $pia_lang['BackDevices_MainScan_disabled'];
$pia_journ_lang['LogStr_9999'] = 'Konfigurationsdatei bearbeitet';

?>