/*
 Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
 For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang("codesnippet","da",{button:"Indsæt kodestykket her",codeContents:"Koden",emptySnippetError:"Kodestykket kan ikke være tomt.",language:"Sprog",title:"Kodestykke",pathName:"kodestykke"});