CKEDITOR.plugins.setLang("mathjax","en-au",{title:"Mathematics in TeX",button:"Maths",dialogInput:"Write your TeX here",docUrl:"http://en.wikibooks.org/wiki/LaTeX/Mathematics",docLabel:"TeX documentation",loading:"loading...",pathName:"maths"});